@@ -46,6 +46,21 @@ public slots:
 protected:
     void paintEvent(QPaintEvent *event);
 
+    /**
+     * 2021.6.24新增
+     * @brief getTooltipBackground 先获取模糊背景图
+     * @return
+     */
+    QPixmap getTooltipBackground();
+    /**
+     * 2021.6.24新增
+     * @brief paintRect  画模糊背景
+     * @param painter
+     * @param blurPixmap  矩形框位置的模糊图形
+     */
+    void paintRect(QPainter &painter,QPixmap &blurPixmap);
+
+
 private:
     QPixmap countdown1Img;
     QPixmap countdown2Img;
@@ -54,8 +69,9 @@ private:
     int showCountdownCounter;
 
     QTimer *showCountdownTimer;
-
     QString text;
+
+
 };
 
 #endif // COUNTDOWNTOOLTIP_H
