@@ -218,6 +218,7 @@ public:
             delete m_pRecorderRegion;
             m_pRecorderRegion = nullptr;
         }
+#ifdef OCR_SCROLL_FLAGE_ON
         if (m_scrollShotTip) {
             delete m_scrollShotTip;
             m_scrollShotTip = nullptr;
@@ -230,6 +231,7 @@ public:
             delete m_previewWidget;
             m_previewWidget = nullptr;
         }
+#endif
 //        if (m_ocrInterface) {
 //            delete m_ocrInterface;
 //            m_ocrInterface = nullptr;
@@ -333,7 +335,7 @@ signals:
     void deleteShapes();
     void changeMicrophoneSelectEvent(bool checked);
     void changeSystemAudioSelectEvent(bool checked);
-
+    void stopRecordArm();
 public slots:
     void onExit();
     /**
@@ -503,7 +505,7 @@ public slots:
     void onScrollShotCheckScrollType(int autoScrollFlag);
 
     /**
-     * @brief 监听锁屏信号，滚动截图和贴图需要使用
+     * @brief 监听锁屏信号，滚动截图和贴图需要使用,贴图或滚动截图时突然锁频会触发此信号槽
      * @param msg
      */
     void onLockScreenEvent(QDBusMessage msg);
@@ -525,7 +527,9 @@ public slots:
      * 2：滚动到底部
      * 3：拼接截图到截图最大限度
      */
+#ifdef OCR_SCROLL_FLAGE_ON
     void onScrollShotMerageImgState(PixMergeThread::MergeErrorValue state);
+#endif
 
     /**
      * @brief initPadShot:初始化平板截图
@@ -560,6 +564,12 @@ protected:
     bool saveImg(const QPixmap &pix, const QString &fileName, const char *format = nullptr);
     void save2Clipboard(const QPixmap &pix);
 
+    /**
+     * @brief 检查传入的字符串是否包含.png | .jpg | .bmp | .jepg
+     * @param 传入的字符串
+     * @return false: 不包含 true:包含
+     */
+    bool checkSuffix(const QString &str);
     virtual void wheelEvent(QWheelEvent *event) override;  // waland手动滚动处理逻辑
 
     /**
@@ -633,8 +643,9 @@ protected:
      * @param previewPostion 预览框相对于捕捉区域的位置
      * @param direction 滚动的方向
      */
+#ifdef OCR_SCROLL_FLAGE_ON
     void scrollShotGrabPixmap(PreviewWidget::PostionStatus previewPostion, int direction, int mosueTime = 0);
-
+#endif
     /**
      * @brief 判断工具栏是否在在捕捉区域内部
      * @return false: 不在  ； true: 在
@@ -652,6 +663,19 @@ protected:
      * @param m_windowStates
      */
     void waylandwindowinfo(const QVector<ClientManagement::WindowState> &m_windowStates);
+    /**
+      * @brief checkTempFileArm
+      * 1050wayland平台上，部分性能差的机型
+      * 采用线程循环监听文件（"/home/" + userName + "/.cache/deepin/deepin-screen-recorder/stopRecord.txt"）是否存在且内容是否为1
+      * 存在且内容是1：停止录屏
+      * 不存在或不为1：不处理
+      */
+    void checkTempFileArm();
+
+    /**
+     * @brief 采用线程循环监听文件（"/home/" + userName + "/.cache/deepin/deepin-screen-recorder/stopRecord.txt"）是否存在且内容是否为1
+     */
+    void whileCheckTempFileArm();
 #endif
     /**
      * @brief 启动截图录屏时检测是否是锁屏状态
@@ -734,7 +758,9 @@ private:
     /**
      * @brief 滚动截图的提示
      */
+#ifdef OCR_SCROLL_FLAGE_ON
     ScrollShotTip *m_scrollShotTip = nullptr;
+#endif
 
     /**
      * @brief 初始化滚动截图时的第一张图
@@ -744,8 +770,9 @@ private:
     /**
      * @brief 获取预览框相对于捕捉区域的位置
      */
+#ifdef OCR_SCROLL_FLAGE_ON
     PreviewWidget::PostionStatus m_previewPostion = PreviewWidget::PostionStatus::RIGHT;
-
+#endif
     /**
      * @brief 滚动截图状态
      * 0：停止(第一次进入)；
@@ -837,6 +864,11 @@ private:
      * @brief 直接通过快捷键或命令行启动滚动截图
      */
     bool m_isDirectStartScrollShot = false;
+
+    /**
+     * @brief 是否进入保存滚动截图。滚动截图模式中，保存时不需要保存蚂蚁线
+     */
+    bool m_isSaveScrollShot = false;
     /**
      * @brief 直接通过快捷键启动ocr
      */
@@ -931,11 +963,11 @@ private:
     RecorderTablet *m_tabletRecorderHandle = nullptr;
     int m_cursorBound;
     //ocr接口
-    OcrInterface *m_ocrInterface;
+    OcrInterface *m_ocrInterface = nullptr;
     /**
      * @brief 贴图接口
      */
-    PinScreenShotsInterface *m_pinInterface;
+    PinScreenShotsInterface *m_pinInterface = nullptr;
     //预览窗口
 #ifdef OCR_SCROLL_FLAGE_ON
     PreviewWidget *m_previewWidget = nullptr;
@@ -957,9 +989,14 @@ private:
     PlasmaWindowManagement *m_windowManagement = nullptr;
     ClientManagement *m_clientManagement = nullptr;
     QVector<ClientManagement::WindowState> m_windowStates;
+    /**
+      * @brief mips平台创建缓存文件的路径
+      */
+    std::string m_tempPath;
 #endif
     bool m_isFullScreenShot = false;
-    bool m_isVertical = false;
+    bool m_isScreenVertical = false; // 判断多屏是否纵向布局
+    bool m_isLockedState = false;
 };
 
 #endif //MAINWINDOW_H
