@@ -38,6 +38,7 @@
 
 */
 #include "mainwindow.h"
+#include "utils.h"
 
 #include <QDebug>
 #include <QDBusInterface>
@@ -49,6 +50,16 @@
 #define MOVENUM 1
 #define WHEELNUM 10
 
+//bool MainWindow::isWaylandProtocol()
+//{
+
+//    QProcessEnvironment e = QProcessEnvironment::systemEnvironment();
+//    QString XDG_SESSION_TYPE = e.value(QStringLiteral("XDG_SESSION_TYPE"));
+//    QString WAYLAND_DISPLAY = e.value(QStringLiteral("WAYLAND_DISPLAY"));
+//    return XDG_SESSION_TYPE == QLatin1String("wayland") ||  WAYLAND_DISPLAY.contains(QLatin1String("wayland"), Qt::CaseInsensitive);
+
+//}
+
 MainWindow::MainWindow(QWidget *parent)
     : DWidget(parent)
 {
@@ -87,6 +98,7 @@ void MainWindow::initMainWindow()
     connect(m_toolBar, SIGNAL(sendOcrButtonClicked()), this, SLOT(onOpenOCR()));
     connect(m_toolBar, SIGNAL(sendSaveButtonClicked()), this, SLOT(onSave()));
     connect(m_toolBar, SIGNAL(sendCloseButtonClicked()), this, SLOT(onExit()));
+
     QWidget::installEventFilter(this);
 }
 
@@ -119,13 +131,13 @@ bool MainWindow::openImageAndName(const QImage &image, const QString &name, cons
     //将坐标点转换为m_pixelRatio屏幕缩放比下的点
     m_showPosition = QPoint(static_cast<int>(point.x() * m_pixelRatio), static_cast<int>(point.y() * m_pixelRatio));
     QRect currnetScreenRect;
-    //查找当前截图贴图区域所在的屏幕
+    //查找当前截图贴图区域所在的屏幕(m_screenInfo中存储已缩放的数据）
     for (int i = 0; i < m_screenInfo.size(); ++i) {
         currnetScreenRect = {
             static_cast<int>(m_screenInfo[i].x),
             static_cast<int>(m_screenInfo[i].y),
-            static_cast<int>(m_screenInfo[i].width),
-            static_cast<int>(m_screenInfo[i].height)
+            static_cast<int>(m_screenInfo[i].width *  m_pixelRatio),
+            static_cast<int>(m_screenInfo[i].height * m_pixelRatio)
         };
         if (currnetScreenRect.contains(m_showPosition)) {
             int x = static_cast<int>((m_showPosition.x() - currnetScreenRect.x()) / m_pixelRatio + currnetScreenRect.x());
@@ -139,6 +151,7 @@ bool MainWindow::openImageAndName(const QImage &image, const QString &name, cons
     move(m_showPosition);
     update();
     proportion = static_cast<double>(this->width())  / this->height();
+    m_isfirstTime = true; //解决119157Bug采用的标识
     updateToolBarPosition();// 更新位置
     return true;
 }
@@ -157,38 +170,63 @@ void MainWindow::saveImg()
 {
     m_saveInfo = m_toolBar->getSaveInfo(); // 获取保存信息
 
-    if (m_saveInfo.first.contains(tr("Desktop"))) {
+    if (m_saveInfo.first == SubToolWidget::DESKTOP) {
         QString savePath = QStandardPaths::standardLocations(QStandardPaths::DesktopLocation).first();
-        QString formatStr = m_saveInfo.second.toLower();
+        QString formatStr;
+        if (m_saveInfo.second == SubToolWidget::PNG) {
+            formatStr = QString("png");
+        } else if (m_saveInfo.second == SubToolWidget::JPG) {
+            formatStr = QString("jpg");
+        } else if (m_saveInfo.second == SubToolWidget::BMP) {
+            formatStr = QString("bmp");
+        }
         m_lastImagePath = QString("%1/%2.%3").arg(savePath).arg(m_imageName).arg(formatStr);
-    } else if (m_saveInfo.first.contains(tr("Pictures"))) {
+    } else if (m_saveInfo.first == SubToolWidget::PICTURES) {
         qDebug() << "save to picture";
         QString savePath = QStandardPaths::standardLocations(QStandardPaths::PicturesLocation).first() + QDir::separator() + "Screenshots";
         if ((!QDir(savePath).exists() && QDir().mkdir(savePath) == false) ||  // 文件不存在，且创建失败
                 (QDir(savePath).exists() && !QFileInfo(savePath).isWritable())) {  // 文件存在，且不能写
             savePath = QStandardPaths::standardLocations(QStandardPaths::PicturesLocation).first();
         }
-        QString formatStr = m_saveInfo.second.toLower();
+        QString formatStr;
+        if (m_saveInfo.second == SubToolWidget::PNG) {
+            formatStr = QString("png");
+        } else if (m_saveInfo.second == SubToolWidget::JPG) {
+            formatStr = QString("jpg");
+        } else if (m_saveInfo.second == SubToolWidget::BMP) {
+            formatStr = QString("bmp");
+        }
         m_lastImagePath = QString("%1/%2.%3").arg(savePath).arg(m_imageName).arg(formatStr);
-    } else if (m_saveInfo.first.contains(tr("Folder"))) {
-        m_toolBar->hide();
+    } else if (m_saveInfo.first == SubToolWidget::FOLDER) {
+        m_toolBar->setHiden();
         qDebug() << "save to path";
-        QString imgName = QString("%1.%2").arg(m_imageName).arg(m_saveInfo.second.toLower());
-        QString saveFileName =  QFileDialog::getSaveFileName(this, tr("Save"),  imgName,
-                                                             tr("JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)"));
+        QString imgName, saveFileName;
+        if (m_saveInfo.second == SubToolWidget::PNG) {
+            imgName = QString("%1.png").arg(m_imageName);
+            saveFileName = QFileDialog::getSaveFileName(this, tr("Save"),  imgName,
+                                                        tr("PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)"));
+        } else if (m_saveInfo.second == SubToolWidget::JPG) {
+            imgName = QString("%1.jpg").arg(m_imageName);
+            saveFileName = QFileDialog::getSaveFileName(this, tr("Save"),  imgName,
+                                                        tr("JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)"));
+        } else if (m_saveInfo.second == SubToolWidget::BMP) {
+            imgName = QString("%1.bmp").arg(m_imageName);
+            saveFileName = QFileDialog::getSaveFileName(this, tr("Save"),  imgName,
+                                                        tr("BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)"));
+        }
         if (saveFileName.isEmpty()) {
             onExit();
             return;
         }
         qDebug() << "saveFileName" << saveFileName;
         m_lastImagePath = saveFileName;
-    } else if (m_saveInfo.first.contains(tr("Clipboard"))) {
+    } else if (m_saveInfo.first == SubToolWidget::CLIPBOARD) {
         qDebug() << "save to clip";
         m_lastImagePath = "";
     }
 
     bool isSaveState = true;
-    if (!m_saveInfo.first.contains(tr("Clipboard"))) {
+    if (m_saveInfo.first != SubToolWidget::CLIPBOARD) {
         isSaveState = m_image.save(m_lastImagePath);
     }
 
@@ -198,6 +236,12 @@ void MainWindow::saveImg()
     QClipboard *cb = qApp->clipboard();
     cb->setMimeData(t_imageData, QClipboard::Clipboard);
 
+    if (Utils::isWaylandMode) {
+        QEventLoop eventloop;
+        connect(cb, SIGNAL(dataChanged()), &eventloop, SLOT(quit()));
+        eventloop.exec();
+    }
+
     // 发送通知
     sendNotify(m_lastImagePath, isSaveState);
 }
@@ -256,7 +300,7 @@ void MainWindow::region(const QPoint &cursorGlobalPoint)
 
 void MainWindow::mousePressEvent(QMouseEvent *event)
 {
-    qDebug() << __FUNCTION__ << __LINE__;
+    //qDebug() << this << __FUNCTION__ << __LINE__ ;
     switch (event->button()) {
     case Qt::LeftButton:
         isLeftPressDown = true;
@@ -266,7 +310,8 @@ void MainWindow::mousePressEvent(QMouseEvent *event)
             dragPosition = event->globalPos() - this->frameGeometry().topLeft();
         }
         if (!m_toolBar->isHidden())
-            m_toolBar->hide(); //隐藏工具栏
+            m_toolBar->setHiden(); //隐藏工具栏
+        //qDebug() << this << __FUNCTION__ << __LINE__ ;
         break;
     case Qt::RightButton:
         handleMouseRightBtn(event);
@@ -344,11 +389,15 @@ void MainWindow::mouseMoveEvent(QMouseEvent *event)
             default:
                 break;
             }
-
             this->setGeometry(rMove);
         } else {
             this->setCursor(QCursor(Qt::ClosedHandCursor));
-            move(event->globalPos() - dragPosition);
+            //qDebug() << "=============event->globalPos()" << event->globalPos() << "dragPosition" << dragPosition;
+            QPoint globalPoint = event->globalPos() - dragPosition;
+            if (Utils::isWaylandMode && globalPoint.y() < 0) {
+                globalPoint.setY(0);
+            }
+            move(globalPoint);
             event->accept();
         }
     }
@@ -357,6 +406,7 @@ void MainWindow::mouseMoveEvent(QMouseEvent *event)
 
 void MainWindow::mouseReleaseEvent(QMouseEvent *event)
 {
+    qDebug() << this << __FUNCTION__ << __LINE__ ;
     if (event->button() == Qt::LeftButton) {
         isLeftPressDown = false;
         if (dir != NONE) {
@@ -374,8 +424,9 @@ void MainWindow::paintEvent(QPaintEvent *e)
     if (!m_image.isNull()) {
         QPainter pp(this);
         QRect Temp(0, 0, this->width(), this->height());
-        QImage tempImage = m_image.scaled(this->width(), this->height(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
-        pp.drawImage(Temp, tempImage);
+        // 用rect获取到的图片不容易失帧
+        //QImage tempImage = m_image.scaled(this->width(), this->height(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+        pp.drawImage(Temp, m_image);
     }
 
 
@@ -393,7 +444,13 @@ void MainWindow::keyPressEvent(QKeyEvent *event)
         this->move(x + MOVENUM, y);
         isNeedUpdateToolBar = true;
     } else if (event->key() == Qt::Key_Up) {
-        this->move(x, y - MOVENUM);
+        // 适配wayland
+        if (y - MOVENUM < 0) {
+            this->move(x, 0);
+        } else {
+            this->move(x, y - MOVENUM);
+        }
+
         isNeedUpdateToolBar = true;
     } else if (event->key() == Qt::Key_Down) {
         this->move(x, y + MOVENUM);
@@ -436,16 +493,26 @@ void MainWindow::wheelEvent(QWheelEvent *event)
 bool MainWindow::eventFilter(QObject *watched, QEvent *event)
 {
     if (watched == this) {
-        //窗口停用，变为不活动的窗口
+        //QEvent::WindowActivate:窗口被激活;QEvent::WindowDeactivate:窗口已停用
         if (QEvent::WindowActivate == event->type()) {
+            //qDebug() <<this<< m_toolBar << __FUNCTION__ << __LINE__ << event->type();
+            //规避wayland下打开贴图1，并在贴图1上重新生成贴图2时，贴图2激活状态不对(工具栏已经设置显示，但实际上未显示。)。
+            if (Utils::isWaylandMode && !isLeftPressDown) {
+                this->m_toolBar->setHiden();
+            }
             updateToolBarPosition();
-            qDebug() << __FUNCTION__ << __LINE__;
+            //规避wayland下打开多个贴图，通过鼠标连续切换贴图时，贴图激活状态不对(工具栏已经设置显示，但实际上未显示。)。
+            if (Utils::isWaylandMode && isLeftPressDown) {
+                this->m_toolBar->setHiden();
+            }
+            //qDebug() <<this<< m_toolBar << __FUNCTION__ << __LINE__ << event->type();
             return false;
         } else if (QEvent::WindowDeactivate == event->type()) {
+            //qDebug() << this << m_toolBar <<__FUNCTION__ << __LINE__ << event->type();
             if (m_toolBar->isActiveWindow())
                 return false;
-            m_toolBar->hide();
-            qDebug() << __FUNCTION__ << __LINE__;
+            m_toolBar->setHiden();
+            //qDebug() << this << m_toolBar <<__FUNCTION__ << __LINE__ << event->type();
             return false;
         }
     }
@@ -488,7 +555,7 @@ void MainWindow::initShortcut()
         // 帮助手册跳转到子标题，传入子标题标签(标签文档内唯一，固定为英文，与翻译无关)
         QList<QVariant> arg;
         arg << (QString("deepin-screen-recorder"))                  // 应用名称
-            << QString("Pin Screenshots");                         // 帮助文案中的标题名称
+            << QString("pinscreenshots");                         // 帮助文案中的标题名称
         interFace.callWithArgumentList(QDBus::AutoDetect, "OpenTitle", arg);
     });
 
@@ -562,7 +629,7 @@ void MainWindow::sendNotify(QString savePath, bool bSaveState)
         QList<QVariant> arg;
         unsigned int id = 0;
         int timeout = -1;
-        arg << QCoreApplication::applicationName() << id << "deepin-screen-recorder" << QString() << tips << QStringList() << QVariantMap() << timeout;
+        arg << tr("Pin Screenshots") << id << "deepin-screen-recorder" << QString() << tips << QStringList() << QVariantMap() << timeout;
         notification.callWithArgumentList(QDBus::AutoDetect, "Notify", arg);
         onExit();
         return;
@@ -585,7 +652,7 @@ void MainWindow::sendNotify(QString savePath, bool bSaveState)
     int timeout = -1;
     unsigned int id = 0;
     QList<QVariant> arg;
-    arg << (QCoreApplication::applicationName())                 // appname
+    arg << tr("Pin Screenshots")                 // appname
         << id                                                    // id
         << QString("deepin-screen-recorder")                     // icon
         << tr("Screenshot finished")                              // summary
@@ -601,17 +668,24 @@ void MainWindow::sendNotify(QString savePath, bool bSaveState)
 void MainWindow::updateToolBarPosition()
 {
     QPoint brPoint = mapToGlobal(this->rect().bottomRight());
-    if ((brPoint.y() + 15 + m_toolBar->height()) >= m_screenSize.height()) {
+    int x = 0, y = 0;
+    qDebug() << "updateToolBarPosition brPoint is" << brPoint;
+    if ((brPoint.y() + 15 + m_toolBar->toolBarHeight()) >= m_screenSize.height()) {
         QPoint trPoint = mapToGlobal(this->rect().topRight());
-        if (trPoint.y() - 15 - m_toolBar->height() <= 0) {
-            m_toolBar->showAt(QPoint(trPoint.x() - m_toolBar->width(), trPoint.y() + 15));
+        if (trPoint.y() - 15 - m_toolBar->toolBarHeight() <= 0) {
+            x = trPoint.x() - m_toolBar->toolBarWidth();
+            y = trPoint.y() + 15;
         } else {
-            m_toolBar->showAt(QPoint(trPoint.x() - m_toolBar->width(), trPoint.y() - 15 - m_toolBar->height()));
+            x = trPoint.x() - m_toolBar->toolBarWidth();
+            y = trPoint.y() - 15 - m_toolBar->toolBarHeight();
         }
     } else {
-        //qDebug() << "m_toolBar->width()" << m_toolBar->width();
-        m_toolBar->showAt(QPoint(brPoint.x() - m_toolBar->width(), brPoint.y() + 15));
+        x = brPoint.x() - m_toolBar->toolBarWidth();
+        y = brPoint.y() + 15;
+        //qDebug() << "m_toolBar->width()" << m_toolBar->toolBarWidth();
     }
+    m_toolBar->showAt(QPoint(x, y), m_isfirstTime);
+    m_isfirstTime = false;
 }
 
 
