@@ -23,12 +23,16 @@
 #define RECORDPROCESS_H
 
 #include "utils/configsettings.h"
+#include "utils/voicevolumewatcher.h"
+#include "gstrecord/gstrecordx.h"
 #ifdef KF5_WAYLAND_FLAGE_ON
 #include "waylandrecord/waylandintegration.h"
 #endif
 #include <QProcess>
 #include <QObject>
 #include <QRect>
+#include <QTimer>
+#include <QtConcurrent>
 
 //不需要开启线程，用信号槽代替 process->waitForFinished(-1); 避免线程等待浪费系统资源
 /**
@@ -74,23 +78,46 @@ public:
      * @brief 停止录屏
      */
     void stopRecord();
-
+    /**
+     * @brief 退出录屏（先停止插件计时，再弹录屏提示，最后退出计时插件）
+     */
+    void exitRecord(QString newSavePath);
+    /**
+     * @brief 定时给任务栏插件发送正在录屏的信号
+     */
+    void emitRecording();
 private:
     /**
-     * @brief x11协议下录制视频
+     * @brief x11协议下ffmpeg录制视频
      */
     void recordVideo();
 
     /**
-     * @brief 开始录制wayland视频
+     * @brief 开始ffmpeg录制wayland视频
      */
     void waylandRecord();
 
+    /**
+     * @brief gstreamer录制视频
+     */
+    void GstStartRecord();
+
+    /**
+     * @brief gstreamer停止录制视频
+     */
+    void GstStopRecord();
+
     /**
      * @brief 初始化进程
      */
     void initProcess();
 public slots:
+    /**
+     * @brief 退出gstreamer录屏
+     * wayland下录屏，需要Gstreamer录屏类触发，以保证Gstreamer管道中的数据已写完
+     * x11下可以直接调用此函数
+     */
+    void onExitGstRecord();
     /**
      * @brief onRecordFinish:是否录制光标
      */
@@ -177,6 +204,15 @@ private:
      * @brief mp4转码成gif的进程
      */
     QProcess *m_pTranscodeProcess = nullptr;
+    /**
+      * @brief 定时发送录屏正在运行的标志
+      */
+    bool m_recordingFlag;
+    /**
+     * @brief gstreamer录屏处理类
+     */
+    GstRecordX *m_gstRecordX;
+
 };
 
 #endif //RECORDPROCESS_H
