@@ -49,6 +49,7 @@ bool Utils::is3rdInterfaceStart = false;
 bool Utils::isTabletEnvironment = false;
 bool Utils::isWaylandMode = false;
 bool Utils::isRootUser = false;
+bool Utils::isFFmpegEnv = true;
 int Utils::themeType = 0;
 
 QString Utils::getQrcPath(QString imageName)
@@ -114,7 +115,7 @@ void Utils::passInputEvent(int wid)
     // Wayland 事件穿透
     if (Utils::isWaylandMode) {
         QWidget *widget = QWidget::find(static_cast<WId>(wid));
-        if(widget && widget->windowHandle()) {
+        if (widget && widget->windowHandle()) {
             widget->windowHandle()->setMask(QRegion(0, 0, 1, 1));
         }
         return;
@@ -150,7 +151,7 @@ void Utils::setAccessibility(QAction *action, const QString name)
 
 void Utils::getInputEvent(const int wid, const short x, const short y, const unsigned short width, const unsigned short height)
 {
-    if(Utils::isWaylandMode == true)
+    if (Utils::isWaylandMode == true)
         return;
     XRectangle *reponseArea = new XRectangle;
     reponseArea->x = x;
@@ -177,7 +178,7 @@ void Utils::getInputEvent(const int wid, const short x, const short y, const uns
 
 void Utils::cancelInputEvent(const int wid, const short x, const short y, const unsigned short width, const unsigned short height)
 {
-    if(Utils::isWaylandMode == true)
+    if (Utils::isWaylandMode == true)
         return;
     XRectangle *reponseArea = new XRectangle;
     reponseArea->x = x;
@@ -221,7 +222,7 @@ bool Utils::isSysHighVersion1040()
 
 void Utils::enableXGrabButton()
 {
-    if(Utils::isWaylandMode == true)
+    if (Utils::isWaylandMode == true)
         return;
     //extern int XGrabButton(
     //    Display *      /* display */,
@@ -245,7 +246,7 @@ void Utils::enableXGrabButton()
 
 void Utils::disableXGrabButton()
 {
-    if(Utils::isWaylandMode == true)
+    if (Utils::isWaylandMode == true)
         return;
     XUngrabButton(QX11Info::display(), true, AnyModifier, DefaultRootWindow(QX11Info::display()));
 
@@ -393,11 +394,20 @@ bool Utils::checkCpuIsZhaoxin()
     QString str_output = process.readAllStandardOutput();
     process.close();
     if (str_output.length() == 0) {
-       return false;
+        return false;
     }
     return true;
 }
 
+//获取处理器名称
+QString Utils::getCpuModelName()
+{
+    if (DSysInfo::cpuModelName().isNull()) {
+        return "";
+    }
+    return DSysInfo::cpuModelName();
+}
+
 void Utils::notSupportWarn()
 {
     DDialog warnDlg;
@@ -406,4 +416,4 @@ void Utils::notSupportWarn()
     warnDlg.addSpacing(20);
     warnDlg.addButton(tr("Exit"));
     warnDlg.exec();
-}
\ No newline at end of file
+}
