@@ -24,6 +24,7 @@
 
 #include <com_deepin_daemon_audio.h>
 #include <com_deepin_daemon_audio_source.h>
+#include <com_deepin_daemon_audio_sink.h>
 
 #include <QObject>
 #include <QTimer>
@@ -57,11 +58,19 @@ signals:
     /* void inputSourceChanged(const QString &name); */
 
 private:
+
+    //音频服务名
     const QString m_serviceName {"com.deepin.daemon.Audio"};
 
+    /**
+     * @brief 音频接口对象
+     * 对应为com.deepin.daemon.Audio
+     */
     QScopedPointer<com::deepin::daemon::Audio> m_audioInterface;
+    /**
+     * @brief 音频源(输入源)
+     */
     QScopedPointer<com::deepin::daemon::audio::Source> m_defaultSource;
-
     struct Port {
         QString  portId;
         QString portName;
