@@ -20,7 +20,7 @@
 
 #include "waylandintegration.h"
 #include "waylandintegration_p.h"
-
+#include "utils.h"
 #include <QDBusArgument>
 #include <QDBusMetaType>
 
@@ -28,15 +28,17 @@
 #include <QLoggingCategory>
 #include <QThread>
 #include <QTimer>
-
+#include <QFile>
+#include <QPainter>
 #include <QImage>
-
+#include <QtConcurrent>
 // KWayland
 #include <KWayland/Client/connection_thread.h>
 #include <KWayland/Client/event_queue.h>
 #include <KWayland/Client/registry.h>
 #include <KWayland/Client/output.h>
 #include <KWayland/Client/remote_access.h>
+#include <KWayland/Client/outputdevice.h>
 
 // system
 #include <fcntl.h>
@@ -64,13 +66,17 @@ Q_LOGGING_CATEGORY(XdgDesktopPortalKdeWaylandIntegration, "xdp-kde-wayland-integ
 //取消自动析构机制，此处后续还需优化
 //Q_GLOBAL_STATIC(WaylandIntegration::WaylandIntegrationPrivate, globalWaylandIntegration)
 static WaylandIntegration::WaylandIntegrationPrivate *globalWaylandIntegration = new  WaylandIntegration::WaylandIntegrationPrivate();
-static int globalImageCount = 0;
 
 void WaylandIntegration::init(QStringList list)
 {
     globalWaylandIntegration->initWayland(list);
 }
 
+void WaylandIntegration::init(QStringList list, GstRecordX *gstRecord)
+{
+    globalWaylandIntegration->initWayland(list, gstRecord);
+}
+
 bool WaylandIntegration::isEGLInitialized()
 {
     return globalWaylandIntegration->isEGLInitialized();
@@ -85,7 +91,18 @@ void WaylandIntegration::stopStreaming()
 
 bool WaylandIntegration::WaylandIntegrationPrivate::stopVideoRecord()
 {
-    return  m_recordAdmin->stopStream();
+    if (Utils::isFFmpegEnv) {
+        if (m_recordAdmin) {
+            return  m_recordAdmin->stopStream();
+        } else {
+            qWarning() << "m_recordAdmin is not init!";
+            return false;
+        }
+    } else {
+        setBGetFrame(false);
+        isGstWriteVideoFrame = false;
+        return true;
+    }
 }
 
 QMap<quint32, WaylandIntegration::WaylandOutput> WaylandIntegration::screens()
@@ -167,7 +184,7 @@ WaylandIntegration::WaylandIntegrationPrivate::WaylandIntegrationPrivate()
     , m_remoteAccessManager(nullptr)
 {
     m_bInit = true;
-#if defined (__mips__) || defined (__sw_64__) || defined (__loongarch_64__)
+#if defined (__mips__) || defined (__sw_64__) || defined (__loongarch_64__) || defined (__loongarch__)
     m_bufferSize = 60;
 #elif defined (__aarch64__)
     m_bufferSize = 60;
@@ -178,9 +195,11 @@ WaylandIntegration::WaylandIntegrationPrivate::WaylandIntegrationPrivate()
     qDBusRegisterMetaType<WaylandIntegrationPrivate::Stream>();
     qDBusRegisterMetaType<WaylandIntegrationPrivate::Streams>();
     m_recordAdmin = nullptr;
+    m_gstRecordX = nullptr;
     //m_writeFrameThread = nullptr;
     m_bInitRecordAdmin = true;
     m_bGetFrame = true;
+    m_screenCount = 1;
     //m_recordTIme = -1;
 }
 
@@ -222,6 +241,7 @@ void WaylandIntegration::WaylandIntegrationPrivate::bindOutput(int outputName, i
 void WaylandIntegration::WaylandIntegrationPrivate::stopStreaming()
 {
     if (m_streamingEnabled) {
+        m_appendFrameToListFlag = false;
         m_streamingEnabled = false;
 
         // First unbound outputs and destroy remote access manager so we no longer receive buffers
@@ -245,8 +265,36 @@ QMap<quint32, WaylandIntegration::WaylandOutput> WaylandIntegration::WaylandInte
 
 void WaylandIntegration::WaylandIntegrationPrivate::initWayland(QStringList list)
 {
+    //通过wayland底层接口获取图片的方式不相同，需要获取电脑的厂商，hw的需要特殊处理
+    m_boardVendorType = getBoardVendorType();
+    qDebug() << "m_boardVendorType: " << m_boardVendorType;
+    //由于性能问题部分非hw的arm机器编码效率低，适当调大视频帧的缓存空间（防止调整的过大导致保存时间延长），且在下面添加视频到缓冲区时进行了降低帧率的处理。
+    if (QSysInfo::currentCpuArchitecture().startsWith("ARM", Qt::CaseInsensitive) && !m_boardVendorType) {
+        m_bufferSize = 200;
+    }
     m_fps = list[5].toInt();
     m_recordAdmin = new RecordAdmin(list, this);
+    m_recordAdmin->setBoardVendor(m_boardVendorType);
+    //初始化wayland服务链接
+    initConnectWayland();
+}
+void WaylandIntegration::WaylandIntegrationPrivate::initWayland(QStringList list, GstRecordX *gstRecord)
+{
+    //通过wayland底层接口获取图片的方式不相同，需要获取电脑的厂商，hw的需要特殊处理
+    m_boardVendorType = getBoardVendorType();
+    qDebug() << "m_boardVendorType: " << m_boardVendorType;
+    //由于性能问题部分非hw的arm机器编码效率低，适当调大视频帧的缓存空间（防止调整的过大导致保存时间延长），且在下面添加视频到缓冲区时进行了降低帧率的处理。
+    if (QSysInfo::currentCpuArchitecture().startsWith("ARM", Qt::CaseInsensitive) && !m_boardVendorType) {
+        m_bufferSize = 200;
+    }
+    m_fps = list[5].toInt();
+    m_gstRecordX = gstRecord;
+    m_gstRecordX->setBoardVendorType(m_boardVendorType);
+    //初始化wayland服务链接
+    initConnectWayland();
+}
+void WaylandIntegration::WaylandIntegrationPrivate::initConnectWayland()
+{
     //设置获取视频帧
     setBGetFrame(true);
 
@@ -284,6 +332,28 @@ void WaylandIntegration::WaylandIntegrationPrivate::initWayland(QStringList list
     m_connection->moveToThread(m_thread);
     m_connection->initConnection();
 }
+int WaylandIntegration::WaylandIntegrationPrivate::getBoardVendorType()
+{
+    QFile file("/sys/class/dmi/id/board_vendor");
+    bool flag = file.open(QIODevice::ReadOnly | QIODevice::Text);
+    if (!flag) {
+        return 0;
+    }
+    QByteArray t = file.readAll();
+    QString result = QString(t);
+    if (result.isEmpty()) {
+        return 0;
+    }
+    file.close();
+    qDebug() << "/sys/class/dmi/id/board_vendor: " << result;
+    qDebug() << "cpu: " << Utils::getCpuModelName();
+    if (result.contains("HUAWEI")) {
+        if (!Utils::getCpuModelName().contains("Kunpeng", Qt::CaseSensitivity::CaseInsensitive)) {
+            return 1;
+        }
+    }
+    return 0;
+}
 
 void WaylandIntegration::WaylandIntegrationPrivate::addOutput(quint32 name, quint32 version)
 {
@@ -310,15 +380,6 @@ void WaylandIntegration::WaylandIntegrationPrivate::addOutput(quint32 name, quin
                 qCWarning(XdgDesktopPortalKdeWaylandIntegration) << "Failed to start streaming: remote access manager interface is not initialized yet";
                 return ;
             }
-            m_remoteAccessManager = m_registry->createRemoteAccessManager(interface.name, interface.version);
-            connect(m_remoteAccessManager, &KWayland::Client::RemoteAccessManager::bufferReady, this, [this](const void *output, const KWayland::Client::RemoteBuffer * rbuf) {
-                Q_UNUSED(output);
-                connect(rbuf, &KWayland::Client::RemoteBuffer::parametersObtained, this, [this, rbuf] {
-                    //processBuffer(rbuf);
-                    processBufferX86(rbuf);
-                });
-            });
-            //            m_output = output.waylandOutputName();
             return ;
         }
         m_outputMap.insert(name, portalOutput);
@@ -335,7 +396,33 @@ void WaylandIntegration::WaylandIntegrationPrivate::removeOutput(quint32 name)
     qCDebug(XdgDesktopPortalKdeWaylandIntegration) << "    model: " << output.model();
 }
 
-void WaylandIntegration::WaylandIntegrationPrivate::processBuffer(const KWayland::Client::RemoteBuffer *rbuf)
+void WaylandIntegration::WaylandIntegrationPrivate::onDeviceChanged(quint32 name, quint32 version)
+{
+    KWayland::Client::OutputDevice *devT = m_registry->createOutputDevice(name, version);
+    if (devT && devT->isValid()) {
+        connect(devT, &KWayland::Client::OutputDevice::changed, this, [ = ]() {
+            qDebug() << devT->uuid() << devT->geometry();
+            // 保存屏幕id和对应位置大小
+            m_screenId2Point.insert(devT->uuid(), devT->geometry());
+            m_screenCount = m_screenId2Point.size();
+
+            // 更新屏幕大小
+            m_screenSize.setWidth(0);
+            m_screenSize.setHeight(0);
+            for (auto p = m_screenId2Point.begin(); p != m_screenId2Point.end(); ++p) {
+                if (p.value().x() + p.value().width() > m_screenSize.width()) {
+                    m_screenSize.setWidth(p.value().x() + p.value().width());
+                }
+                if (p.value().y() + p.value().height() > m_screenSize.height()) {
+                    m_screenSize.setHeight(p.value().y() + p.value().height());
+                }
+            }
+            qDebug() << "屏幕大小:" << m_screenSize;
+        });
+    }
+}
+
+void WaylandIntegration::WaylandIntegrationPrivate::processBuffer(const KWayland::Client::RemoteBuffer *rbuf, const QRect rect)
 {
     //qDebug() << Q_FUNC_INFO;
     QScopedPointer<const KWayland::Client::RemoteBuffer> guard(rbuf);
@@ -347,18 +434,51 @@ void WaylandIntegration::WaylandIntegrationPrivate::processBuffer(const KWayland
     //        return;
     if (m_bInitRecordAdmin) {
         m_bInitRecordAdmin = false;
-        m_recordAdmin->init(static_cast<int>(width), static_cast<int>(height));
-        frameStartTime = avlibInterface::m_av_gettime();
+        if (Utils::isFFmpegEnv) {
+            m_recordAdmin->init(static_cast<int>(m_screenSize.width()), static_cast<int>(m_screenSize.height()));
+            frameStartTime = avlibInterface::m_av_gettime();
+        } else {
+            frameStartTime = QDateTime::currentMSecsSinceEpoch();
+            isGstWriteVideoFrame = true;
+            if (m_gstRecordX) {
+                m_gstRecordX->waylandGstStartRecord();
+            } else {
+                qWarning() << "m_gstRecordX is nullptr!";
+            }
+            QtConcurrent::run(this, &WaylandIntegrationPrivate::gstWriteVideoFrame);
+        }
+        m_appendFrameToListFlag = true;
+        QtConcurrent::run(this, &WaylandIntegrationPrivate::appendFrameToList);
     }
     unsigned char *mapData = static_cast<unsigned char *>(mmap(nullptr, stride * height, PROT_READ, MAP_SHARED, dma_fd, 0));
     if (MAP_FAILED == mapData) {
         qCWarning(XdgDesktopPortalKdeWaylandIntegration) << "dma fd " << dma_fd << " mmap failed - ";
     }
-    appendBuffer(mapData, static_cast<int>(width), static_cast<int>(height), static_cast<int>(stride), avlibInterface::m_av_gettime() - frameStartTime);
+    //appendBuffer(mapData, static_cast<int>(width), static_cast<int>(height), static_cast<int>(stride), avlibInterface::m_av_gettime() - frameStartTime);
+    if (m_screenCount == 1) {
+        m_curNewImage.first = 0;//avlibInterface::m_av_gettime() - frameStartTime;
+        {
+            QMutexLocker locker(&m_bGetScreenImageMutex);
+            m_curNewImage.second = QImage(mapData, width, height, QImage::Format_RGBA8888).copy();
+        }
+    } else {
+        //QString pngName = QDateTime::currentDateTime().toString(QLatin1String("hh:mm:ss.zzz ") + QString("%1_").arg(rect.x()));
+        //QImage(mapData, width, height, QImage::Format_RGBA8888).copy().save(pngName + ".png");
+        m_ScreenDateBuf.append(QPair<QRect, QImage>(rect, QImage(mapData, width, height, QImage::Format_RGBA8888).copy()));
+        if (m_ScreenDateBuf.size() ==  m_screenCount) {
+            QMutexLocker locker(&m_bGetScreenImageMutex);
+            m_curNewImageScreen.clear();
+            for (auto itr = m_ScreenDateBuf.begin(); itr != m_ScreenDateBuf.end(); ++itr) {
+                m_curNewImageScreen.append(*itr);
+            }
+            m_ScreenDateBuf.clear();
+        }
+    }
     munmap(mapData, stride * height);
     close(dma_fd);
 }
-void WaylandIntegration::WaylandIntegrationPrivate::processBufferX86(const KWayland::Client::RemoteBuffer *rbuf)
+
+void WaylandIntegration::WaylandIntegrationPrivate::processBufferX86(const KWayland::Client::RemoteBuffer *rbuf, const QRect rect)
 {
     QScopedPointer<const KWayland::Client::RemoteBuffer> guard(rbuf);
     auto dma_fd = rbuf->fd();
@@ -367,89 +487,149 @@ void WaylandIntegration::WaylandIntegrationPrivate::processBufferX86(const KWayl
     quint32 stride = rbuf->stride();
     if (m_bInitRecordAdmin) {
         m_bInitRecordAdmin = false;
-        m_recordAdmin->init(static_cast<int>(width), static_cast<int>(height));
-        frameStartTime = avlibInterface::m_av_gettime();
+        if (Utils::isFFmpegEnv) {
+            m_recordAdmin->init(static_cast<int>(m_screenSize.width()), static_cast<int>(m_screenSize.height()));
+            frameStartTime = avlibInterface::m_av_gettime();
+        } else {
+            frameStartTime = QDateTime::currentMSecsSinceEpoch();
+            isGstWriteVideoFrame = true;
+            if (m_gstRecordX) {
+                m_gstRecordX->waylandGstStartRecord();
+            } else {
+                qWarning() << "m_gstRecordX is nullptr!";
+            }
+            QtConcurrent::run(this, &WaylandIntegrationPrivate::gstWriteVideoFrame);
+        }
+        m_appendFrameToListFlag = true;
+        QtConcurrent::run(this, &WaylandIntegrationPrivate::appendFrameToList);
     }
-    // unsigned char *imageData = getImageData(dma_fd, width, height, stride, rbuf->format());
-    QImage img = getImage(dma_fd, width, height, stride, rbuf->format());
-    if (img.isNull()) {
-        qDebug() << "获取图片失败！";
-        return ;
-    }
-
-    int step = 0;
-    switch (m_fps) {
-    case 5:
-        step = 6;
-        break;
-    case 10:
-        step = 3;
-        break;
-    case 20:
-        step = 2;
-        break;
-    default:
-        step = 0;
-    }
-    if (step != 0) {
-        if (globalImageCount % step != 0) {
-            appendBuffer(img.bits(), static_cast<int>(width), static_cast<int>(height), static_cast<int>(stride), avlibInterface::m_av_gettime() - frameStartTime);
+    QImage img(m_screenSize, QImage::Format_RGBA8888);
+    if (m_screenCount == 1) {
+        m_curNewImage.first = 0;//avlibInterface::m_av_gettime() - frameStartTime;
+        {
+            QMutexLocker locker(&m_bGetScreenImageMutex);
+            m_curNewImage.second = getImage(dma_fd, width, height, stride, rbuf->format());
         }
     } else {
-        appendBuffer(img.bits(), static_cast<int>(width), static_cast<int>(height), static_cast<int>(stride), avlibInterface::m_av_gettime() - frameStartTime);
+        m_ScreenDateBuf.append(QPair<QRect, QImage>(rect, getImage(dma_fd, width, height, stride, rbuf->format())));
+        if (m_ScreenDateBuf.size() ==  m_screenCount) {
+            QMutexLocker locker(&m_bGetScreenImageMutex);
+            m_curNewImageScreen.clear();
+            for (auto itr = m_ScreenDateBuf.begin(); itr != m_ScreenDateBuf.end(); ++itr) {
+                m_curNewImageScreen.append(*itr);
+            }
+            m_ScreenDateBuf.clear();
+        }
     }
-
-    globalImageCount++;
     close(dma_fd);
 }
-
-unsigned char *WaylandIntegration::WaylandIntegrationPrivate::getImageData(int32_t fd, uint32_t width, uint32_t height, uint32_t stride, uint32_t format)
+//通过线程每30ms钟向数据池中取出一张图片添加到环形缓冲区，以便后续视频编码
+void WaylandIntegration::WaylandIntegrationPrivate::appendFrameToList()
 {
-    QImage tempImage;
-    tempImage = QImage(static_cast<int>(width), static_cast<int>(height), QImage::Format_RGBA8888);
-    eglMakeCurrent(m_eglstruct.dpy, EGL_NO_SURFACE, EGL_NO_SURFACE, m_eglstruct.ctx);
-    EGLint importAttributes[] = {EGL_WIDTH,
-                                 static_cast<int>(width),
-                                 EGL_HEIGHT,
-                                 static_cast<int>(height),
-                                 EGL_LINUX_DRM_FOURCC_EXT,
-                                 static_cast<int>(format),
-                                 EGL_DMA_BUF_PLANE0_FD_EXT,
-                                 fd,
-                                 EGL_DMA_BUF_PLANE0_OFFSET_EXT,
-                                 0,
-                                 EGL_DMA_BUF_PLANE0_PITCH_EXT,
-                                 static_cast<int>(stride),
-                                 EGL_NONE
-                                };
-    EGLImageKHR image = eglCreateImageKHR(m_eglstruct.dpy, EGL_NO_CONTEXT, EGL_LINUX_DMA_BUF_EXT, nullptr, importAttributes);
-    if (image == EGL_NO_IMAGE_KHR) {
-        qDebug() << "未获取到图片！！！";
-        return nullptr;
+    int64_t delayTime = 1000 / m_fps  + 1;
+    //qDebug() << "delayTime: " << delayTime;
+#ifdef __mips__
+    //delayTime = 150;
+#endif
+    //qDebug() << "QDateTime::currentMSecsSinceEpoch(): " << QDateTime::currentMSecsSinceEpoch() << " , avlibInterface::m_av_gettime(): " << avlibInterface::m_av_gettime();
+    while (m_appendFrameToListFlag) {
+        if (m_screenCount == 1) {
+            QImage tempImage;
+            {
+                QMutexLocker locker(&m_bGetScreenImageMutex);
+                tempImage = m_curNewImage.second.copy();
+            }
+            if (!tempImage.isNull()) {
+                //qDebug() << "用来编码的帧索引glovbalImageCount: " << globalImageCount;
+                int64_t temptime = 0;
+                if (Utils::isFFmpegEnv) {
+                    temptime = avlibInterface::m_av_gettime();
+
+                } else {
+                    temptime = QDateTime::currentMSecsSinceEpoch();
+
+                }
+                appendBuffer(tempImage.bits(), static_cast<int>(tempImage.width()), static_cast<int>(tempImage.height()),
+                             static_cast<int>(tempImage.width() * 4), temptime/*- frameStartTime*/);
+            }
+            QThread::msleep(static_cast<unsigned long>(delayTime));
+        } else {
+            //多屏录制
+            int64_t curFramTime = 0;
+            if (Utils::isFFmpegEnv) {
+                curFramTime = avlibInterface::m_av_gettime();
+
+            } else {
+                curFramTime = QDateTime::currentMSecsSinceEpoch();
+
+            }
+#if 0
+            cv::Mat res;
+            res.create(cv::Size(m_screenSize.width(), m_screenSize.height()), CV_8UC4);
+            res = cv::Scalar::all(0);
+            for (auto itr = m_curNewImageScreen.begin(); itr != m_curNewImageScreen.end(); ++itr) {
+                cv::Mat temp = cv::Mat(itr->second.height(), itr->second.width(), CV_8UC4,
+                                       const_cast<uchar *>(itr->second.bits()), static_cast<size_t>(itr->second.bytesPerLine()));
+                temp.copyTo(res(cv::Rect(itr->first.x(), itr->first.y(), itr->first.width(), itr->first.height())));
+            }
+            m_curNewImageScreen.clear();
+            QImage img = QImage(res.data, res.cols, res.rows, static_cast<int>(res.step), QImage::Format_RGBA8888);
+#else
+
+            QVector<QPair<QRect, QImage>> tempImageVec;
+            {
+                QMutexLocker locker(&m_bGetScreenImageMutex);
+                if (m_curNewImageScreen.size() != m_screenCount) continue;
+                for (auto itr = m_curNewImageScreen.begin(); itr != m_curNewImageScreen.end(); ++itr) {
+                    tempImageVec.append(*itr);
+                }
+            }
+            QImage img(m_screenSize, QImage::Format_RGBA8888);
+            img.fill(Qt::GlobalColor::black);
+            QPainter painter(&img);
+            for (auto itr = tempImageVec.begin(); itr != tempImageVec.end(); ++itr) {
+                painter.drawImage(itr->first.topLeft(), itr->second);
+            }
+            tempImageVec.clear();
+#endif
+            appendBuffer(img.bits(), img.width(), img.height(), img.width() * 4, curFramTime - frameStartTime);
+            // 计算拼接的时的耗时
+            int64_t t = 0;
+            if (Utils::isFFmpegEnv) {
+                t = (avlibInterface::m_av_gettime() - curFramTime) / 1000;
+
+            } else {
+                t = (QDateTime::currentMSecsSinceEpoch() - curFramTime) / 1000;
+
+            }
+            qDebug() << delayTime - t;
+            if (t < delayTime) {
+                QThread::msleep(static_cast<unsigned long>(delayTime - t));
+            }
+        }
+    }
+}
+//通过线程循环向gstreamer管道写入视频帧数据
+void WaylandIntegration::WaylandIntegrationPrivate::gstWriteVideoFrame()
+{
+    waylandFrame frame;
+    while (isWriteVideo()) {
+        if (getFrame(frame)) {
+            if (m_gstRecordX) {
+                m_gstRecordX->waylandWriteVideoFrame(frame._frame, frame._width, frame._height);
+            } else {
+                qWarning() << "m_gstRecordX is nullptr!";
+            }
+        } else {
+            //qDebug() << "视频缓冲区无数据！";
+        }
+    }
+    //等待wayland视频环形队列中的视频帧，全部写入管道
+    if (m_gstRecordX) {
+        m_gstRecordX->waylandGstStopRecord();
+    } else {
+        qWarning() << "m_gstRecordX is nullptr!";
     }
-
-    // create GL 2D texture for framebuffer
-    GLuint texture;
-    glGenTextures(1, &texture);
-    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
-    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
-    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE);
-    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE);
-    glBindTexture(GL_TEXTURE_2D, texture);
-    glEGLImageTargetTexture2DOES(GL_TEXTURE_2D, image);
-
-    GLuint fbo;
-    glGenFramebuffers(1, &fbo);
-    glBindFramebuffer(GL_FRAMEBUFFER, fbo);
-    glFramebufferTexture2D(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_TEXTURE_2D, texture, 0);
-    glReadPixels(0, 0, width, height, GL_RGBA, GL_UNSIGNED_BYTE, tempImage.bits());
-    glBindFramebuffer(GL_FRAMEBUFFER, 0);
-
-    glDeleteFramebuffers(1, &fbo);
-    glDeleteTextures(1, &texture);
-    eglDestroyImageKHR(m_eglstruct.dpy, image);
-
-    return tempImage.bits();
 }
 QImage WaylandIntegration::WaylandIntegrationPrivate::getImage(int32_t fd, uint32_t width, uint32_t height, uint32_t stride, uint32_t format)
 {
@@ -509,12 +689,33 @@ void WaylandIntegration::WaylandIntegrationPrivate::setupRegistry()
 
     connect(m_registry, &KWayland::Client::Registry::outputAnnounced, this, &WaylandIntegrationPrivate::addOutput);
     connect(m_registry, &KWayland::Client::Registry::outputRemoved, this, &WaylandIntegrationPrivate::removeOutput);
-
+    connect(m_registry, &KWayland::Client::Registry::outputDeviceAnnounced, this, &WaylandIntegrationPrivate::onDeviceChanged);
     connect(m_registry, &KWayland::Client::Registry::interfacesAnnounced, this, [this] {
         m_registryInitialized = true;
         //qCDebug(XdgDesktopPortalKdeWaylandIntegration) << "Registry initialized";
     });
 
+
+    connect(m_registry, &KWayland::Client::Registry::remoteAccessManagerAnnounced, this,
+    [this](quint32 name, quint32 version) {
+        Q_UNUSED(name);
+        Q_UNUSED(version);
+        m_remoteAccessManager = m_registry->createRemoteAccessManager(m_registry->interface(KWayland::Client::Registry::Interface::RemoteAccessManager).name, m_registry->interface(KWayland::Client::Registry::Interface::RemoteAccessManager).version);
+        connect(m_remoteAccessManager, &KWayland::Client::RemoteAccessManager::bufferReady, this, [this](const void *output, const KWayland::Client::RemoteBuffer * rbuf) {
+            QRect screenGeometry = (KWayland::Client::Output::get(reinterpret_cast<wl_output *>(const_cast<void *>(output))))->geometry();
+            connect(rbuf, &KWayland::Client::RemoteBuffer::parametersObtained, this, [this, rbuf, screenGeometry] {
+                if (m_boardVendorType)
+                {
+                    processBuffer(rbuf, screenGeometry);
+                } else
+                {
+                    processBufferX86(rbuf, screenGeometry);
+                }
+            });
+        });
+    }
+           );
+
     m_registry->create(m_connection);
     m_registry->setEventQueue(m_queue);
     m_registry->setup();
@@ -565,7 +766,6 @@ void WaylandIntegration::WaylandIntegrationPrivate::appendBuffer(unsigned char *
     if (!bGetFrame() || nullptr == frame || width <= 0 || height <= 0) {
         return;
     }
-
     int size = height * stride;
     unsigned char *ch = nullptr;
     if (m_bInit) {
@@ -617,6 +817,7 @@ void WaylandIntegration::WaylandIntegrationPrivate::appendBuffer(unsigned char *
             m_freeList.removeFirst();
         }
     }
+    //qDebug() << "存视频帧 m_waylandList.size(): " << m_waylandList.size() << " , m_freeList.size(): " << m_freeList.size();
 }
 
 int WaylandIntegration::WaylandIntegrationPrivate::frameIndex = 0;
@@ -647,6 +848,7 @@ bool WaylandIntegration::WaylandIntegrationPrivate::getFrame(waylandFrame &frame
         //回收空闲内存，重复使用
         m_freeList.append(wFrame._frame);
         //qDebug() << "获取视频帧";
+        //qDebug() << "获取视频帧 m_waylandList.size(): " << m_waylandList.size() << " , m_freeList.size(): " << m_freeList.size();
         return true;
     }
 }
@@ -654,11 +856,16 @@ bool WaylandIntegration::WaylandIntegrationPrivate::getFrame(waylandFrame &frame
 bool WaylandIntegration::WaylandIntegrationPrivate::isWriteVideo()
 {
     QMutexLocker locker(&m_mutex);
-    if (m_recordAdmin->m_writeFrameThread->bWriteFrame()) {
-        return true;
+    if (Utils::isFFmpegEnv) {
+        if (m_recordAdmin->m_writeFrameThread->bWriteFrame()) {
+            return true;
+        }
     } else {
-        return !m_waylandList.isEmpty();
+        if (isGstWriteVideoFrame) {
+            return true;
+        }
     }
+    return !m_waylandList.isEmpty();
 }
 
 bool WaylandIntegration::WaylandIntegrationPrivate::bGetFrame()
