@@ -41,17 +41,14 @@ DGUI_USE_NAMESPACE
 DWIDGET_USE_NAMESPACE
 
 namespace {
-    const int TOOLBAR_HEIGHT = 223;
-    const int TOOLBAR_WIDTH = 40;
-    const int BUTTON_SPACING = 3;
-    //const int SHOT_BUTTON_SPACING = 3;
-    //const int COLOR_NUM = 16;
-    const QSize TOOL_ICON_SIZE = QSize(30, 30);
-    const QSize TOOL_BUTTON_SIZE = QSize(38, 38);
-    const QSize TOOL_SLIDERBlUR_SIZE = QSize(35, 190);
-    const QSize TOOL_SLIDER_SIZE = QSize(40, 180);
-    const QSize SPLITTER_SIZE = QSize(30, 1);
-    //const QSize MIN_TOOL_BUTTON_SIZE = QSize(35, 30);
+const int TOOLBAR_HEIGHT = 223;
+const int TOOLBAR_WIDTH = 40;
+const int BUTTON_SPACING = 3;
+const QSize TOOL_ICON_SIZE = QSize(30, 30);
+const QSize TOOL_BUTTON_SIZE = QSize(38, 38);
+const QSize TOOL_SLIDERBlUR_SIZE = QSize(35, 190);
+const QSize TOOL_SLIDER_SIZE = QSize(40, 180);
+const QSize SPLITTER_SIZE = QSize(30, 1);
 }
 
 ShotToolWidget::ShotToolWidget(DWidget *parent) :
@@ -64,31 +61,10 @@ ShotToolWidget::ShotToolWidget(DWidget *parent) :
     initWidget();
 }
 
-ShotToolWidget::~ShotToolWidget()
-{
-//指定父指针，利用qt对象树自动析构机制释放资源
-//    if(nullptr != m_buttonGroup){
-//        m_buttonGroup->deleteLater();
-//        m_buttonGroup = nullptr;
-//    }
-//    if(nullptr != m_thicknessBtnGroup){
-//        m_thicknessBtnGroup->deleteLater();
-//        m_thicknessBtnGroup = nullptr;
-//    }
-//    if(nullptr != m_funcBtnGroup){
-//        m_funcBtnGroup->deleteLater();
-//        m_funcBtnGroup = nullptr;
-//    }
-//    if(nullptr != m_rectLayout){
-//        m_rectLayout->deleteLater();
-//        m_rectLayout = nullptr;
-//    }
-}
+
 
 void ShotToolWidget::initWidget()
 {
-    m_themeType = 0;
-    m_themeType = ConfigSettings::instance()->value("common", "themeType").toInt();
     setFixedSize(TOOLBAR_WIDTH, TOOLBAR_HEIGHT);
     m_arrowFlag = false;
 
@@ -155,47 +131,59 @@ void ShotToolWidget::initRectLabel()
     }
 
     connect(t_thicknessBtnGroup, QOverload<int>::of(&QButtonGroup::buttonClicked),
-            [ = ](int status) {
+    [ = ](int status) {
         Q_UNUSED(status);
         //DPalette pa;
         if (thickOneBtn->isChecked()) {
             thickOneBtn->update();
             ConfigSettings::instance()->setValue("rectangle", "linewidth_index", 0);
-            if(m_blurRectButton && m_blurRectButton->isChecked())
+            if (m_blurRectButton && m_blurRectButton->isChecked())
                 m_blurRectButton->click();
-            if(m_mosaicRectButton && m_mosaicRectButton->isChecked())
+            if (m_mosaicRectButton && m_mosaicRectButton->isChecked())
                 m_mosaicRectButton->click();
         }
 
         if (thickTwoBtn->isChecked()) {
             thickTwoBtn->update();
             ConfigSettings::instance()->setValue("rectangle", "linewidth_index", 1);
-            if(m_blurRectButton && m_blurRectButton->isChecked())
+            if (m_blurRectButton && m_blurRectButton->isChecked())
                 m_blurRectButton->click();
-            if(m_mosaicRectButton && m_mosaicRectButton->isChecked())
+            if (m_mosaicRectButton && m_mosaicRectButton->isChecked())
                 m_mosaicRectButton->click();
         }
 
         if (thickThreeBtn->isChecked()) {
             thickThreeBtn->update();
             ConfigSettings::instance()->setValue("rectangle", "linewidth_index", 2);
-            if(m_blurRectButton && m_blurRectButton->isChecked())
+            if (m_blurRectButton && m_blurRectButton->isChecked())
                 m_blurRectButton->click();
-            if(m_mosaicRectButton && m_mosaicRectButton->isChecked())
+            if (m_mosaicRectButton && m_mosaicRectButton->isChecked())
                 m_mosaicRectButton->click();
         }
     });
 
-    thickOneBtn->click();
-    ConfigSettings::instance()->setValue("rectangle", "linewidth_index", 0);
+
+    int linewidth_index = ConfigSettings::instance()->value("rectangle", "linewidth_index").toInt();
+    if (linewidth_index == 0) {
+        thickOneBtn->click();
+    } else if (linewidth_index == 1) {
+        thickTwoBtn->click();
+    } else {
+        thickThreeBtn->click();
+    }
 
     rectLayout->addSpacing(2);
+    //分割线
     ToolButton *t_seperator = new ToolButton(this);
-    pa = t_seperator->palette();
-    pa.setColor(DPalette::Light, QColor("#1C1C1C"));
-    pa.setColor(DPalette::Dark, QColor("#1C1C1C"));
+    if (Utils::themeType == 1) {
+        //t_seperator->setStyleSheet("border:1px groove rgba(0, 0, 0, 77);border-radius:0px");
+        t_seperator->setStyleSheet("border:0px solid rgba(0, 0, 0, 77);border-radius:0px;background-color:rgba(0, 0, 0, 77)");
+    } else {
+        //t_seperator->setStyleSheet("border:1px groove rgba(255, 255, 255, 26);border-radius:0px;");
+        t_seperator->setStyleSheet("border:0px solid rgba(255, 255, 255, 26);border-radius:0px;background-color:rgba(255, 255, 255, 26)");
+    }
+
     t_seperator->setDisabled(true);
-    t_seperator->setPalette(pa);
     t_seperator->setFixedSize(SPLITTER_SIZE);
     rectLayout->addWidget(t_seperator, 0, Qt::AlignHCenter);
     rectLayout->addSpacing(BUTTON_SPACING);
@@ -227,13 +215,15 @@ void ShotToolWidget::initRectLabel()
 
     connect(m_blurRectButton, &ToolButton::clicked, this, [ = ] {
         bool t_status = m_blurRectButton->isChecked();
-        if (t_status == true){
+        if (t_status == true)
+        {
             ConfigSettings::instance()->setValue("rectangle", "is_blur", m_blurRectButton->isChecked());
 
             m_mosaicRectButton->setChecked(false);
             m_mosaicRectButton->update();
             ConfigSettings::instance()->setValue("rectangle", "is_mosaic", m_mosaicRectButton->isChecked());
-        } else {
+        } else
+        {
             m_blurRectButton->setChecked(false);
             m_blurRectButton->update();
             ConfigSettings::instance()->setValue("rectangle", "is_blur", m_blurRectButton->isChecked());
@@ -242,13 +232,15 @@ void ShotToolWidget::initRectLabel()
 
     connect(m_mosaicRectButton, &ToolButton::clicked, this, [ = ] {
         bool t_status = m_mosaicRectButton->isChecked();
-        if (t_status == true){
+        if (t_status == true)
+        {
             ConfigSettings::instance()->setValue("rectangle", "is_mosaic", m_mosaicRectButton->isChecked());
             m_arrowFlag = true;
             m_blurRectButton->setChecked(false);
             m_blurRectButton->update();
             ConfigSettings::instance()->setValue("rectangle", "is_blur", m_blurRectButton->isChecked());
-        } else {
+        } else
+        {
             m_mosaicRectButton->setChecked(false);
             m_mosaicRectButton->update();
             ConfigSettings::instance()->setValue("rectangle", "is_mosaic", m_mosaicRectButton->isChecked());
@@ -263,13 +255,18 @@ void ShotToolWidget::initRectLabel()
 
     rectLayout->addSpacing(2);
     ToolButton *t_seperator1 = new ToolButton(this);
-    pa = t_seperator1->palette();
-    pa.setColor(DPalette::Light, QColor("#1C1C1C"));
-    pa.setColor(DPalette::Dark, QColor("#1C1C1C"));
+    if (Utils::themeType == 1) {
+        //t_seperator1->setStyleSheet("border:1px groove rgba(0, 0, 0, 77);border-radius:0px");
+        t_seperator1->setStyleSheet("border:0px solid rgba(0, 0, 0, 77);border-radius:0px;background-color:rgba(0, 0, 0, 77)");
+    } else {
+        //t_seperator1->setStyleSheet("border:1px groove rgba(255, 255, 255, 26);border-radius:0px");
+        t_seperator1->setStyleSheet("border:0px solid rgba(255, 255, 255, 26);border-radius:0px;background-color:rgba(255, 255, 255, 26)");
+    }
+    qDebug() << "test";
     t_seperator1->setDisabled(true);
-    t_seperator1->setPalette(pa);
     t_seperator1->setFixedSize(SPLITTER_SIZE);
     rectLayout->addWidget(t_seperator1, 0, Qt::AlignHCenter);
+    rectLayout->addSpacing(2);
     m_rectSubTool->setLayout(rectLayout);
     addWidget(m_rectSubTool);
 }
@@ -326,15 +323,15 @@ void ShotToolWidget::initCircLabel()
     }
 
     connect(m_thicknessBtnGroup, QOverload<int>::of(&QButtonGroup::buttonClicked),
-            [ = ](int status) {
+    [ = ](int status) {
         Q_UNUSED(status);
         //DPalette pa;
         if (thickOneBtn->isChecked()) {
             thickOneBtn->update();
             ConfigSettings::instance()->setValue("oval", "linewidth_index", 0);
-            if(m_blurCircButton && m_blurCircButton->isChecked())
+            if (m_blurCircButton && m_blurCircButton->isChecked())
                 m_blurCircButton->click();
-            if(m_mosaicCircButton && m_mosaicCircButton->isChecked())
+            if (m_mosaicCircButton && m_mosaicCircButton->isChecked())
                 m_mosaicCircButton->click();
         } else {
             thickOneBtn->update();
@@ -343,9 +340,9 @@ void ShotToolWidget::initCircLabel()
         if (thickTwoBtn->isChecked()) {
             thickTwoBtn->update();
             ConfigSettings::instance()->setValue("oval", "linewidth_index", 1);
-            if(m_blurCircButton && m_blurCircButton->isChecked())
+            if (m_blurCircButton && m_blurCircButton->isChecked())
                 m_blurCircButton->click();
-            if(m_mosaicCircButton && m_mosaicCircButton->isChecked())
+            if (m_mosaicCircButton && m_mosaicCircButton->isChecked())
                 m_mosaicCircButton->click();
         } else {
             thickTwoBtn->update();
@@ -354,24 +351,35 @@ void ShotToolWidget::initCircLabel()
         if (thickThreeBtn->isChecked()) {
             thickThreeBtn->update();
             ConfigSettings::instance()->setValue("oval", "linewidth_index", 2);
-            if(m_blurCircButton && m_blurCircButton->isChecked())
+            if (m_blurCircButton && m_blurCircButton->isChecked())
                 m_blurCircButton->click();
-            if(m_mosaicCircButton && m_mosaicCircButton->isChecked())
+            if (m_mosaicCircButton && m_mosaicCircButton->isChecked())
                 m_mosaicCircButton->click();
         } else {
             thickThreeBtn->update();
         }
     });
-    thickOneBtn->click();
-    ConfigSettings::instance()->setValue("oval", "linewidth_index", 0);
+
+    int linewidth_index = ConfigSettings::instance()->value("oval", "linewidth_index").toInt();
+    if (linewidth_index == 0) {
+        thickOneBtn->click();
+    } else if (linewidth_index == 1) {
+        thickTwoBtn->click();
+    } else {
+        thickThreeBtn->click();
+    }
+
 
     m_rectLayout->addSpacing(2);
     ToolButton *t_seperator = new ToolButton(this);
-    pa = t_seperator->palette();
-    pa.setColor(DPalette::Light, QColor("#1C1C1C"));
-    pa.setColor(DPalette::Dark, QColor("#1C1C1C"));
+    if (Utils::themeType == 1) {
+        //t_seperator->setStyleSheet("border:1px groove rgba(0, 0, 0, 77);border-radius:0px");
+        t_seperator->setStyleSheet("border:0px solid rgba(0, 0, 0, 77);border-radius:0px;background-color:rgba(0, 0, 0, 77)");
+    } else {
+        //t_seperator->setStyleSheet("border:1px groove rgba(255, 255, 255, 26);border-radius:0px");
+        t_seperator->setStyleSheet("border:0px solid rgba(255, 255, 255, 26);border-radius:0px;background-color:rgba(255, 255, 255, 26)");
+    }
     t_seperator->setDisabled(true);
-    t_seperator->setPalette(pa);
     t_seperator->setFixedSize(SPLITTER_SIZE);
     m_rectLayout->addWidget(t_seperator, 0, Qt::AlignHCenter);
     m_rectLayout->addSpacing(BUTTON_SPACING);
@@ -404,7 +412,8 @@ void ShotToolWidget::initCircLabel()
     connect(m_blurCircButton, &ToolButton::clicked, this, [ = ] {
         bool t_status = m_blurCircButton->isChecked();
 
-        if (t_status == true){
+        if (t_status == true)
+        {
 
             ConfigSettings::instance()->setValue("oval", "is_blur", m_blurCircButton->isChecked());
 
@@ -412,7 +421,8 @@ void ShotToolWidget::initCircLabel()
             m_mosaicCircButton->update();
             ConfigSettings::instance()->setValue("oval", "is_mosaic", m_mosaicCircButton->isChecked());
 
-        } else {
+        } else
+        {
             m_blurCircButton->setChecked(false);
             m_blurCircButton->update();
             ConfigSettings::instance()->setValue("oval", "is_blur", m_blurCircButton->isChecked());
@@ -422,13 +432,15 @@ void ShotToolWidget::initCircLabel()
     connect(m_mosaicCircButton, &ToolButton::clicked, this, [ = ] {
         bool t_status = m_mosaicCircButton->isChecked();
 
-        if (t_status == true){
+        if (t_status == true)
+        {
             ConfigSettings::instance()->setValue("oval", "is_mosaic", m_mosaicCircButton->isChecked());
             m_arrowFlag = true;
             m_blurCircButton->setChecked(false);
             m_blurCircButton->update();
             ConfigSettings::instance()->setValue("oval", "is_blur", m_blurCircButton->isChecked());
-        } else {
+        } else
+        {
             m_mosaicCircButton->setChecked(false);
             m_mosaicCircButton->update();
             ConfigSettings::instance()->setValue("oval", "is_mosaic", m_mosaicCircButton->isChecked());
@@ -445,14 +457,18 @@ void ShotToolWidget::initCircLabel()
 
     m_rectLayout->addSpacing(2);
     ToolButton *t_seperator1 = new ToolButton(this);
-    pa = t_seperator1->palette();
-    pa.setColor(DPalette::Light, QColor("#1C1C1C"));
-    pa.setColor(DPalette::Dark, QColor("#1C1C1C"));
+    if (Utils::themeType == 1) {
+        //t_seperator1->setStyleSheet("border:1px groove rgba(0, 0, 0, 77);border-radius:0px");
+        t_seperator1->setStyleSheet("border:0px solid rgba(0, 0, 0, 77);border-radius:0px;background-color:rgba(0, 0, 0, 77)");
+    } else {
+        //t_seperator1->setStyleSheet("border:1px groove rgba(255, 255, 255, 26);border-radius:0px");
+        t_seperator1->setStyleSheet("border:0px solid rgba(255, 255, 255, 26);border-radius:0px;background-color:rgba(255, 255, 255, 26)");
+    }
     t_seperator1->setDisabled(true);
-    t_seperator1->setPalette(pa);
     t_seperator1->setFixedSize(SPLITTER_SIZE);
     m_rectLayout->addWidget(t_seperator1, 0, Qt::AlignHCenter);
 
+    m_rectLayout->addSpacing(2);
     m_circSubTool->setLayout(m_rectLayout);
     addWidget(m_circSubTool);
 }
@@ -509,7 +525,7 @@ void ShotToolWidget::initLineLabel()
     }
 
     connect(t_thicknessBtnGroup, QOverload<int>::of(&QButtonGroup::buttonClicked),
-            [ = ](int status) {
+    [ = ](int status) {
         Q_UNUSED(status);
         if (thickOneBtn->isChecked()) {
             thickOneBtn->update();
@@ -535,18 +551,26 @@ void ShotToolWidget::initLineLabel()
             thickThreeBtn->update();
         }
     });
-    thickOneBtn->click();
 
-    ConfigSettings::instance()->setValue("arrow", "arrow_linewidth_index", 0);
-    ConfigSettings::instance()->setValue("arrow", "straightline_linewidth_index", 0);
+    int linewidth_index = ConfigSettings::instance()->value("arrow", "arrow_linewidth_index").toInt();
+    if (linewidth_index == 0) {
+        thickOneBtn->click();
+    } else if (linewidth_index == 1) {
+        thickTwoBtn->click();
+    } else {
+        thickThreeBtn->click();
+    }
 
     rectLayout->addSpacing(2);
     ToolButton *t_seperator = new ToolButton(this);
-    pa = t_seperator->palette();
-    pa.setColor(DPalette::Light, QColor("#1C1C1C"));
-    pa.setColor(DPalette::Dark, QColor("#1C1C1C"));
+    if (Utils::themeType == 1) {
+        //t_seperator->setStyleSheet("border:1px groove rgba(0, 0, 0, 77);border-radius:0px");
+        t_seperator->setStyleSheet("border:0px solid rgba(0, 0, 0, 77);border-radius:0px;background-color:rgba(0, 0, 0, 77)");
+    } else {
+        //t_seperator->setStyleSheet("border:1px groove rgba(255, 255, 255, 26);border-radius:0px");
+        t_seperator->setStyleSheet("border:0px solid rgba(255, 255, 255, 26);border-radius:0px;background-color:rgba(255, 255, 255, 26)");
+    }
     t_seperator->setDisabled(true);
-    t_seperator->setPalette(pa);
     t_seperator->setFixedSize(SPLITTER_SIZE);
     rectLayout->addWidget(t_seperator, 0, Qt::AlignHCenter);
     rectLayout->addSpacing(BUTTON_SPACING);
@@ -577,7 +601,8 @@ void ShotToolWidget::initLineLabel()
         emit changeArrowAndLine(0);
         ConfigSettings::instance()->setValue("arrow", "is_straight", true);
         m_arrowFlag = false;
-        if (blurButton->isChecked()){
+        if (blurButton->isChecked())
+        {
             mosaicBtn->setChecked(false);
             mosaicBtn->setIcon(QIcon::fromTheme("Arrow-normal"));
             mosaicBtn->update();
@@ -588,7 +613,8 @@ void ShotToolWidget::initLineLabel()
         emit changeArrowAndLine(1);
         ConfigSettings::instance()->setValue("arrow", "is_straight", false);
         m_arrowFlag = true;
-        if (mosaicBtn->isChecked()){
+        if (mosaicBtn->isChecked())
+        {
             blurButton->setChecked(false);
             blurButton->update();
         }
@@ -598,7 +624,7 @@ void ShotToolWidget::initLineLabel()
     if (t_arrowStatus) {
         blurButton->click();
         m_arrowFlag = true;
-    }else {
+    } else {
         mosaicBtn->click();
         m_arrowFlag = false;
     }
@@ -611,13 +637,19 @@ void ShotToolWidget::initLineLabel()
 
     rectLayout->addSpacing(2);
     ToolButton *t_seperator1 = new ToolButton(this);
-    pa = t_seperator1->palette();
-    pa.setColor(DPalette::Light, QColor("#1C1C1C"));
-    pa.setColor(DPalette::Dark, QColor("#1C1C1C"));
+    if (Utils::themeType == 1) {
+        //t_seperator1->setStyleSheet("border:1px groove rgba(0, 0, 0, 77);border-radius:0px");
+        t_seperator1->setStyleSheet("border:0px solid rgba(0, 0, 0, 77);border-radius:0px;background-color:rgba(0, 0, 0, 77)");
+    } else {
+        //t_seperator1->setStyleSheet("border:1px groove rgba(255, 255, 255, 26);border-radius:0px");
+        t_seperator1->setStyleSheet("border:0px solid rgba(255, 255, 255, 26);border-radius:0px;background-color:rgba(255, 255, 255, 26)");
+    }
+
     t_seperator1->setDisabled(true);
     t_seperator1->setPalette(pa);
     t_seperator1->setFixedSize(SPLITTER_SIZE);
     rectLayout->addWidget(t_seperator1, 0, Qt::AlignHCenter);
+    rectLayout->addSpacing(2);
 
     m_lineSubTool->setLayout(rectLayout);
     addWidget(m_lineSubTool);
@@ -672,7 +704,7 @@ void ShotToolWidget::initPenLabel()
     }
 
     connect(t_thicknessBtnGroup, QOverload<int>::of(&QButtonGroup::buttonClicked),
-            [ = ](int status) {
+    [ = ](int status) {
         Q_UNUSED(status);
         //DPalette pa;
         if (thickOneBtn->isChecked()) {
@@ -692,25 +724,36 @@ void ShotToolWidget::initPenLabel()
         if (thickThreeBtn->isChecked()) {
             thickThreeBtn->update();
             ConfigSettings::instance()->setValue("line", "linewidth_index", 2);
-        }else {
+        } else {
             thickThreeBtn->update();
         }
     });
-    thickOneBtn->click();
-    ConfigSettings::instance()->setValue("line", "linewidth_index", 0);
+
+    int linewidth_index = ConfigSettings::instance()->value("line", "linewidth_index").toInt();
+    if (linewidth_index == 0) {
+        thickOneBtn->click();
+    } else if (linewidth_index == 1) {
+        thickTwoBtn->click();
+    } else {
+        thickThreeBtn->click();
+    }
 
 
-    rectLayout->addSpacing(70);
+    //rectLayout->addSpacing(70);
+    rectLayout->addSpacing(40);
     ToolButton *t_seperator = new ToolButton(this);
-    pa = t_seperator->palette();
-    pa.setColor(DPalette::Light, QColor("#1C1C1C"));
-    pa.setColor(DPalette::Dark, QColor("#1C1C1C"));
+    if (Utils::themeType == 1) {
+        //t_seperator->setStyleSheet("border:1px groove rgba(0, 0, 0, 77);border-radius:0px");
+        t_seperator->setStyleSheet("border:0px solid rgba(0, 0, 0, 77);border-radius:0px;background-color:rgba(0, 0, 0, 77)");
+    } else {
+        //t_seperator->setStyleSheet("border:1px groove rgba(255, 255, 255, 26);border-radius:0px");
+        t_seperator->setStyleSheet("border:0px solid rgba(255, 255, 255, 26);border-radius:0px;background-color:rgba(255, 255, 255, 26)");
+    }
     t_seperator->setDisabled(true);
-    t_seperator->setPalette(pa);
     t_seperator->setFixedSize(SPLITTER_SIZE);
     rectLayout->addWidget(t_seperator, 0, Qt::AlignHCenter);
-    rectLayout->addSpacing(70);
-
+    //rectLayout->addSpacing(70);
+    rectLayout->addSpacing(40);
     btnList.clear();
 
     m_penSubTool->setLayout(rectLayout);
@@ -733,7 +776,7 @@ void ShotToolWidget::initTextLabel()
 
     QVBoxLayout *t_blurAreaLayout = new QVBoxLayout(this);
 
-    DSlider *t_textFontSize = new DSlider(Qt::Vertical,this);
+    DSlider *t_textFontSize = new DSlider(Qt::Vertical, this);
 
     t_textFontSize->slider()->setTickInterval(1);
     t_textFontSize->setFixedSize(TOOL_SLIDER_SIZE);
@@ -745,52 +788,12 @@ void ShotToolWidget::initTextLabel()
 
     static const int indexTofontsize[11] = {9, 10, 12, 14, 18, 24, 36, 48, 64, 72, 96};
     int t_fontSize = ConfigSettings::instance()->value("text", "fontsize").toInt();
-    for(int i = 0; i < 11; ++i) {
-        if(indexTofontsize[i] == t_fontSize){
+    for (int i = 0; i < 11; ++i) {
+        if (indexTofontsize[i] == t_fontSize) {
             t_textFontSize->setValue(i);
             break;
         }
     }
-
-    /*
-    switch (t_fontSize) {
-    case 9:
-        t_textFontSize->setValue(0);
-        break;
-    case 10:
-        t_textFontSize->setValue(1);
-        break;
-    case 12:
-        t_textFontSize->setValue(2);
-        break;
-    case 14:
-        t_textFontSize->setValue(3);
-        break;
-    case 18:
-        t_textFontSize->setValue(4);
-        break;
-    case 24:
-        t_textFontSize->setValue(5);
-        break;
-    case 36:
-        t_textFontSize->setValue(6);
-        break;
-    case 48:
-        t_textFontSize->setValue(7);
-        break;
-    case 64:
-        t_textFontSize->setValue(8);
-        break;
-    case 72:
-        t_textFontSize->setValue(9);
-        break;
-    case 96:
-        t_textFontSize->setValue(10);
-        break;
-    default:
-        break;
-    }
-    */
     t_blurAreaLayout->setContentsMargins(0, 0, 0, 0);
     t_blurAreaLayout->addWidget(t_textFontSize, Qt::AlignVCenter);
     t_blurArea->setLayout(t_blurAreaLayout);
@@ -798,46 +801,6 @@ void ShotToolWidget::initTextLabel()
     connect(t_textFontSize, &DSlider::valueChanged, this, [ = ] {
         int t_value = t_textFontSize->value();
         ConfigSettings::instance()->setValue("text", "fontsize", indexTofontsize[t_value]);
-        /*
-        switch (t_value)
-        {
-        case 0:
-            ConfigSettings::instance()->setValue("text", "fontsize", 9);
-            break;
-        case 1:
-            ConfigSettings::instance()->setValue("text", "fontsize", 10);
-            break;
-        case 2:
-            ConfigSettings::instance()->setValue("text", "fontsize", 12);
-            break;
-        case 3:
-            ConfigSettings::instance()->setValue("text", "fontsize", 14);
-            break;
-        case 4:
-            ConfigSettings::instance()->setValue("text", "fontsize", 18);
-            break;
-        case 5:
-            ConfigSettings::instance()->setValue("text", "fontsize", 24);
-            break;
-        case 6:
-            ConfigSettings::instance()->setValue("text", "fontsize", 36);
-            break;
-        case 7:
-            ConfigSettings::instance()->setValue("text", "fontsize", 48);
-            break;
-        case 8:
-            ConfigSettings::instance()->setValue("text", "fontsize", 64);
-            break;
-        case 9:
-            ConfigSettings::instance()->setValue("text", "fontsize", 72);
-            break;
-        case 10:
-            ConfigSettings::instance()->setValue("text", "fontsize", 96);
-            break;
-        default:
-            break;
-        }
-        */
     });
 
     QVBoxLayout *rectLayout = new QVBoxLayout(this);
@@ -872,7 +835,7 @@ void ShotToolWidget::switchContent(QString shapeType)
                 initCircLabel();
                 setCurrentWidget(m_circSubTool);
                 m_circInitFlag = true;
-            }else {
+            } else {
                 setCurrentWidget(m_circSubTool);
             }
         }
@@ -883,7 +846,7 @@ void ShotToolWidget::switchContent(QString shapeType)
                 initLineLabel();
                 setCurrentWidget(m_lineSubTool);
                 m_lineInitFlag = true;
-            }else {
+            } else {
                 setCurrentWidget(m_lineSubTool);
             }
         }
@@ -905,7 +868,7 @@ void ShotToolWidget::switchContent(QString shapeType)
                 initTextLabel();
                 setCurrentWidget(m_textSubTool);
                 m_textInitFlag = true;
-            }else {
+            } else {
                 setCurrentWidget(m_textSubTool);
             }
         }
@@ -915,14 +878,34 @@ void ShotToolWidget::colorChecked(QString colorType)
 {
     Q_UNUSED(colorType);
     //if(m_currentType == "rectangle"){
-    if(m_blurRectButton && m_blurRectButton->isChecked())
+    if (m_blurRectButton && m_blurRectButton->isChecked())
         m_blurRectButton->click();
-    if(m_mosaicRectButton && m_mosaicRectButton->isChecked())
+    if (m_mosaicRectButton && m_mosaicRectButton->isChecked())
         m_mosaicRectButton->click();
     //}else if(m_currentType == "oval"){
-    if(m_blurCircButton && m_blurCircButton->isChecked())
+    if (m_blurCircButton && m_blurCircButton->isChecked())
         m_blurCircButton->click();
-    if(m_mosaicCircButton && m_mosaicCircButton->isChecked())
+    if (m_mosaicCircButton && m_mosaicCircButton->isChecked())
         m_mosaicCircButton->click();
     // }
 }
+ShotToolWidget::~ShotToolWidget()
+{
+//指定父指针，利用qt对象树自动析构机制释放资源
+//    if(nullptr != m_buttonGroup){
+//        m_buttonGroup->deleteLater();
+//        m_buttonGroup = nullptr;
+//    }
+//    if(nullptr != m_thicknessBtnGroup){
+//        m_thicknessBtnGroup->deleteLater();
+//        m_thicknessBtnGroup = nullptr;
+//    }
+//    if(nullptr != m_funcBtnGroup){
+//        m_funcBtnGroup->deleteLater();
+//        m_funcBtnGroup = nullptr;
+//    }
+//    if(nullptr != m_rectLayout){
+//        m_rectLayout->deleteLater();
+//        m_rectLayout = nullptr;
+//    }
+}
