@@ -91,7 +91,7 @@ ToolBarWidget::ToolBarWidget(MainWindow *pMainwindow, DWidget *parent)
 
     setFixedHeight(TOOLBAR_HEIGHT);
     if (Utils::is3rdInterfaceStart) {
-        m_subTool->setMinimumWidth(TOOLBAR_WIDTH - 178); //减去隐藏按钮的最小宽度和
+        m_subTool->setMinimumWidth(TOOLBAR_WIDTH - 160); //减去隐藏按钮的最小宽度和
     }
 
     QHBoxLayout *hLayout = new QHBoxLayout();
@@ -162,6 +162,16 @@ void ToolBarWidget::setPinScreenshotsEnable(const bool &state)
     m_subTool->setPinScreenshotsEnable(state);
 
 }
+
+void ToolBarWidget::setOcrScreenshotsEnable(const bool &state)
+{
+    m_subTool->setOcrScreenshotEnable(state);
+}
+
+void ToolBarWidget::setButEnableOnLockScreen(const bool &state)
+{
+    m_subTool->setButEnableOnLockScreen(state);
+}
 /*
 bool ToolBarWidget::isButtonChecked()
 {
@@ -303,6 +313,16 @@ void ToolBar::setPinScreenshotsEnable(const bool &state)
     m_toolbarWidget->setPinScreenshotsEnable(state);
 }
 
+void ToolBar::setOcrScreenshotsEnable(const bool &state)
+{
+    m_toolbarWidget->setOcrScreenshotsEnable(state);
+}
+
+void ToolBar::setButEnableOnLockScreen(const bool &state)
+{
+    m_toolbarWidget->setButEnableOnLockScreen(state);
+}
+
 void ToolBar::showAt(QPoint pos)
 {
     if (!isVisible())
