@@ -22,6 +22,7 @@
 #ifndef ZOOMINDICATOR_H
 #define ZOOMINDICATOR_H
 
+#include "zoomIndicatorGL.h"
 #include <DLabel>
 #include <DWidget>
 #include <QPainter>
@@ -37,6 +38,7 @@ public:
     ~ZoomIndicator();
 
     void showMagnifier(QPoint pos);
+    void hideMagnifier();
 
 protected:
     void paintEvent(QPaintEvent *);
@@ -45,6 +47,7 @@ private:
     QRect m_globalRect;
     QRect m_centerRect;
     QBrush m_lastCenterPosBrush;
+    ZoomIndicatorGL *m_zoomIndicatorGL = nullptr;
 };
 
 #endif // MAGNIFIER_H
