@@ -7,7 +7,8 @@
 #include "../../../src/dde-dock-plugins/recordtime/recordtimeplugin.h"
 
 namespace  {
-class TestRecordTimePlugin : public testing::Test {
+class TestRecordTimePlugin : public testing::Test
+{
 public:
 
     void SetUp() override
@@ -30,22 +31,22 @@ static const QString PLUGIN_DISPLAY_NAME = QString("deepin-screen-recorder");
 
 TEST_F(TestRecordTimePlugin, pluginName)
 {
-    EXPECT_EQ(PLUGIN_NAME,m_recordTimePlugin->pluginName());
+    EXPECT_EQ(PLUGIN_NAME, m_recordTimePlugin->pluginName());
 }
 
 TEST_F(TestRecordTimePlugin, pluginDisplayName)
 {
-    EXPECT_EQ(PLUGIN_DISPLAY_NAME,m_recordTimePlugin->pluginDisplayName());
+    EXPECT_EQ(PLUGIN_DISPLAY_NAME, m_recordTimePlugin->pluginDisplayName());
 }
 
 TEST_F(TestRecordTimePlugin, pluginIsAllowDisable)
 {
-    EXPECT_EQ(true,m_recordTimePlugin->pluginIsAllowDisable());
+    EXPECT_EQ(true, m_recordTimePlugin->pluginIsAllowDisable());
 }
 
 TEST_F(TestRecordTimePlugin, itemWidget)
 {
-    EXPECT_TRUE( nullptr != m_recordTimePlugin->itemWidget("dummy") );
+    EXPECT_TRUE(nullptr != m_recordTimePlugin->itemWidget("dummy"));
 }
 
 TEST_F(TestRecordTimePlugin, onStart)
@@ -55,6 +56,7 @@ TEST_F(TestRecordTimePlugin, onStart)
 
 TEST_F(TestRecordTimePlugin, onStop)
 {
+    m_recordTimePlugin->m_checkTimer = new QTimer();
     emit m_recordTimePlugin->m_dBusService->stop();
 }
 
@@ -62,3 +64,23 @@ TEST_F(TestRecordTimePlugin, refresh)
 {
     m_recordTimePlugin->refresh();
 }
+
+TEST_F(TestRecordTimePlugin, onRecording)
+{
+    m_recordTimePlugin->m_bshow = true;
+    m_recordTimePlugin->m_dBusService->recording();
+}
+
+TEST_F(TestRecordTimePlugin, onPause)
+{
+    m_recordTimePlugin->m_bshow = true;
+    m_recordTimePlugin->m_dBusService->pause();
+}
+TEST_F(TestRecordTimePlugin, onStopTimes)
+{
+    m_recordTimePlugin->m_checkTimer = new QTimer();
+    emit m_recordTimePlugin->m_dBusService->stop();
+    //连续点击，触发停止信号
+    emit m_recordTimePlugin->m_dBusService->stop();
+    EXPECT_EQ(nullptr, m_recordTimePlugin->m_checkTimer);
+}
