@@ -3,12 +3,14 @@
 #include <QDebug>
 #include <QCameraInfo>
 #include <QDBusMessage>
+#include <QPixmap>
 #include <QtDBus>
 #ifdef ENABLE_TSAN_TOOL
 #include <sanitizer/asan_interface.h>
 #endif
 #include "test_all_interfaces.h"
 #include "stub.h"
+#include "../../src/main_window.h"
 
 static Stub globalStub;
 
@@ -31,13 +33,21 @@ bool isNull_stub(void *obj)
 {
     return false;
 }
+
+bool MainWindow_saveImg_stub(void *obj, const QPixmap &pix, const QString& fileName, const char* format = nullptr)
+{
+    return true;
+}
+
+ACCESS_PRIVATE_FUN(MainWindow, bool(const QPixmap&, const QString&, const char*), saveImg);
+
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
     qDebug() << "start test cases ..............";
     globalStub.set(ADDR(QCameraInfo, availableCameras), availableCameras_stub);
     globalStub.set(ADDR(QCameraInfo, isNull), isNull_stub);
-    //globalStub.set(ADDR(QCoreApplication, quit), quit_stub);
+    globalStub.set(get_private_fun::MainWindowsaveImg(), MainWindow_saveImg_stub);
     globalStub.set(ADDR(QDBusInterface, callWithArgumentList), callWithArgumentList_stub);
     //testing::GTEST_FLAG(output) = "xml:./report/report.xml";
     testing::InitGoogleTest(&argc, argv);
