@@ -14,6 +14,17 @@ or press the shortcut again to stop recording</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>IconWidget</name>
+    <message>
+        <source>Screenshot</source>
+        <translation type="unfinished">لقطة شاشة</translation>
+    </message>
+    <message>
+        <source>Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>MainToolWidget</name>
     <message>
@@ -99,6 +110,10 @@ or press the shortcut again to stop recording</source>
         <source>Scrollshot</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -115,6 +130,13 @@ or press the shortcut again to stop recording</source>
         <translation>خروج</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RecordProcess</name>
     <message>
@@ -338,6 +360,17 @@ or press the shortcut again to stop recording</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>ShotStartPlugin</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished">إلتقاط الشاشة</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation type="unfinished">لقطة شاشة</translation>
+    </message>
+</context>
 <context>
     <name>ShotToolWidget</name>
     <message>
@@ -512,7 +545,15 @@ or press the shortcut again to stop recording</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Pin screenshots</source>
+        <source>Pin Screenshots</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ogg</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
