@@ -12,6 +12,17 @@ o haga clic en el icono de la bandeja</translation>
         <translation>No gire la pantalla durante la grabación</translation>
     </message>
 </context>
+<context>
+    <name>IconWidget</name>
+    <message>
+        <source>Screenshot</source>
+        <translation>Captura de pantalla</translation>
+    </message>
+    <message>
+        <source>Recording</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>MainToolWidget</name>
     <message>
@@ -97,6 +108,10 @@ o haga clic en el icono de la bandeja</translation>
         <source>Scrollshot</source>
         <translation>Capturar desplazamiento</translation>
     </message>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation>Anclar captura de pantalla</translation>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -113,6 +128,13 @@ o haga clic en el icono de la bandeja</translation>
         <translation>Salir</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation>Anclar captura de pantalla</translation>
+    </message>
+</context>
 <context>
     <name>RecordProcess</name>
     <message>
@@ -333,7 +355,18 @@ o haga clic en el icono de la bandeja</translation>
     </message>
     <message>
         <source>Pin screenshots</source>
-        <translation type="unfinished"/>
+        <translation>Anclar captura de pantalla</translation>
+    </message>
+</context>
+<context>
+    <name>ShotStartPlugin</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation>Captura de pantalla</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Captura de pantalla</translation>
     </message>
 </context>
 <context>
@@ -510,7 +543,15 @@ o haga clic en el icono de la bandeja</translation>
         <translation>Capturar desplazamiento</translation>
     </message>
     <message>
-        <source>Pin screenshots</source>
+        <source>Pin Screenshots</source>
+        <translation>Anclar captura de pantalla</translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>ogg</source>
         <translation type="unfinished"/>
     </message>
 </context>
