@@ -12,6 +12,17 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
         <translation>Älä kierrä näyttöä tallennuksen aikana</translation>
     </message>
 </context>
+<context>
+    <name>IconWidget</name>
+    <message>
+        <source>Screenshot</source>
+        <translation>Ruudunkaappaus</translation>
+    </message>
+    <message>
+        <source>Recording</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>MainToolWidget</name>
     <message>
@@ -97,6 +108,10 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
         <source>Scrollshot</source>
         <translation>Vierittävä kaappaus</translation>
     </message>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation>Kiinnitä kaappaukset</translation>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -113,6 +128,13 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
         <translation>Poistu</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation>Kiinnitä kaappaukset</translation>
+    </message>
+</context>
 <context>
     <name>RecordProcess</name>
     <message>
@@ -336,6 +358,17 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
         <translation>Kiinnitä kuvakaappaukset</translation>
     </message>
 </context>
+<context>
+    <name>ShotStartPlugin</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation>Ruudunkaappaus</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Ruudunkaappaus</translation>
+    </message>
+</context>
 <context>
     <name>ShotToolWidget</name>
     <message>
@@ -510,8 +543,16 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
         <translation>Vierittävä kaappaus</translation>
     </message>
     <message>
-        <source>Pin screenshots</source>
-        <translation>Kiinnitä kuvakaappaukset</translation>
+        <source>Pin Screenshots</source>
+        <translation>Kiinnitä kaappaukset</translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>ogg</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
