@@ -12,6 +12,17 @@ atau klik pintasan sekali lagi untuk hentikan rakaman</translation>
         <translation>Jangan putar skrin anda ketika merakam</translation>
     </message>
 </context>
+<context>
+    <name>IconWidget</name>
+    <message>
+        <source>Screenshot</source>
+        <translation>Tangkap Layar</translation>
+    </message>
+    <message>
+        <source>Recording</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>MainToolWidget</name>
     <message>
@@ -97,6 +108,10 @@ atau klik pintasan sekali lagi untuk hentikan rakaman</translation>
         <source>Scrollshot</source>
         <translation>Tangkap tatal</translation>
     </message>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -113,6 +128,13 @@ atau klik pintasan sekali lagi untuk hentikan rakaman</translation>
         <translation>Keluar</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>RecordProcess</name>
     <message>
@@ -336,6 +358,17 @@ atau klik pintasan sekali lagi untuk hentikan rakaman</translation>
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>ShotStartPlugin</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation>Tangkap Skrin</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Tangkap Layar</translation>
+    </message>
+</context>
 <context>
     <name>ShotToolWidget</name>
     <message>
@@ -510,7 +543,15 @@ atau klik pintasan sekali lagi untuk hentikan rakaman</translation>
         <translation>Tangkap tatal</translation>
     </message>
     <message>
-        <source>Pin screenshots</source>
+        <source>Pin Screenshots</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>ogg</source>
         <translation type="unfinished"/>
     </message>
 </context>
