@@ -12,6 +12,17 @@ ou pressione novamente o atalho para parar de gravar</translation>
         <translation>Não rodar o seu ecrã durante a gravação</translation>
     </message>
 </context>
+<context>
+    <name>IconWidget</name>
+    <message>
+        <source>Screenshot</source>
+        <translation>Captura de ecrã</translation>
+    </message>
+    <message>
+        <source>Recording</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>MainToolWidget</name>
     <message>
@@ -97,6 +108,10 @@ ou pressione novamente o atalho para parar de gravar</translation>
         <source>Scrollshot</source>
         <translation>Scrollshot</translation>
     </message>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation>Afixar capturas de ecrã</translation>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -113,6 +128,13 @@ ou pressione novamente o atalho para parar de gravar</translation>
         <translation>Sair</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation>Afixar capturas de ecrã</translation>
+    </message>
+</context>
 <context>
     <name>RecordProcess</name>
     <message>
@@ -336,6 +358,17 @@ ou pressione novamente o atalho para parar de gravar</translation>
         <translation>Afixar capturas de ecrã</translation>
     </message>
 </context>
+<context>
+    <name>ShotStartPlugin</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation>Captura de ecrã</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Captura de ecrã</translation>
+    </message>
+</context>
 <context>
     <name>ShotToolWidget</name>
     <message>
@@ -510,9 +543,17 @@ ou pressione novamente o atalho para parar de gravar</translation>
         <translation>Scrollshot</translation>
     </message>
     <message>
-        <source>Pin screenshots</source>
+        <source>Pin Screenshots</source>
         <translation>Afixar capturas de ecrã</translation>
     </message>
+    <message>
+        <source>webm</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>ogg</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
