@@ -11,6 +11,17 @@ or press the shortcut again to stop recording</source>
         <translation>ئېكراننى سىنغا ئالغاندا ئېكراننى يانتۇ قىلماڭ</translation>
     </message>
 </context>
+<context>
+    <name>IconWidget</name>
+    <message>
+        <source>Screenshot</source>
+        <translation>رەسىم تۇتۇش</translation>
+    </message>
+    <message>
+        <source>Recording</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>MainToolWidget</name>
     <message>
@@ -96,6 +107,10 @@ or press the shortcut again to stop recording</source>
         <source>Scrollshot</source>
         <translation>سىيرىلما سۈرەت تۇتۇش</translation>
     </message>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation>چاپلاق</translation>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -112,6 +127,13 @@ or press the shortcut again to stop recording</source>
         <translation>چېكىنىش</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation>چاپلاق</translation>
+    </message>
+</context>
 <context>
     <name>RecordProcess</name>
     <message>
@@ -335,6 +357,17 @@ or press the shortcut again to stop recording</source>
         <translation>چاپلاق</translation>
     </message>
 </context>
+<context>
+    <name>ShotStartPlugin</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation>ئېكراننى رەسىم تۇتۇش، سىنغا ئېلىش</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>رەسىم تۇتۇش</translation>
+    </message>
+</context>
 <context>
     <name>ShotToolWidget</name>
     <message>
@@ -509,9 +542,17 @@ or press the shortcut again to stop recording</source>
         <translation>سىيرىلما سۈرەت تۇتۇش</translation>
     </message>
     <message>
-        <source>Pin screenshots</source>
+        <source>Pin Screenshots</source>
         <translation>چاپلاق</translation>
     </message>
+    <message>
+        <source>webm</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>ogg</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
