@@ -12,6 +12,17 @@ or press the shortcut again to stop recording</source>
         <translation>屏幕录制中请勿旋转屏幕</translation>
     </message>
 </context>
+<context>
+    <name>IconWidget</name>
+    <message>
+        <source>Screenshot</source>
+        <translation>截图</translation>
+    </message>
+    <message>
+        <source>Recording</source>
+        <translation>录屏</translation>
+    </message>
+</context>
 <context>
     <name>MainToolWidget</name>
     <message>
@@ -97,6 +108,10 @@ or press the shortcut again to stop recording</source>
         <source>Scrollshot</source>
         <translation>滚动截图</translation>
     </message>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation>贴图</translation>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -113,6 +128,13 @@ or press the shortcut again to stop recording</source>
         <translation>退出</translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation>贴图</translation>
+    </message>
+</context>
 <context>
     <name>RecordProcess</name>
     <message>
@@ -336,6 +358,17 @@ or press the shortcut again to stop recording</source>
         <translation>贴图</translation>
     </message>
 </context>
+<context>
+    <name>ShotStartPlugin</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation>截图录屏</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>截图</translation>
+    </message>
+</context>
 <context>
     <name>ShotToolWidget</name>
     <message>
@@ -510,9 +543,17 @@ or press the shortcut again to stop recording</source>
         <translation>滚动截图</translation>
     </message>
     <message>
-        <source>Pin screenshots</source>
+        <source>Pin Screenshots</source>
         <translation>贴图</translation>
     </message>
+    <message>
+        <source>webm</source>
+        <translation>webm</translation>
+    </message>
+    <message>
+        <source>ogg</source>
+        <translation>ogg</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
